#************************************************************************
#
# The contents of this file are subject to the Mozilla Public License
# Version 1.1 (the "License"); you may not use this file except in
# compliance with the License. You may obtain a copy of the License at
# http://www.mozilla.org/MPL/
#
# Software distributed under the License is distributed on an "AS IS"
# basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
# License for the specific language governing rights and limitations
# under the License.
#
#
# The Original Code is Open-site.
#
# The Initial Developer of the Original Code is Open-site.org Website.
#
# Portions created by Open-site.org are Copyright (C) 2002.
# All Rights Reserved.
#
#************************************************************************


package EditorProfile;

use Editor;
use Storage;
use Settings;
use TS;
use UI;

# Generates the HTML code in order to list the privs for a given editor
# Params: 1
# Param 1: the name of the editor
# Returns: 1 (always)

sub listPrivs
{
	my ($ename) = @_;

	#---Open List Of CatEditalls
	open(EDITALL, "$path_data/dirmod.gf");
	$meta = <EDITALL>;
	close(EDITALL);
	#---Close list

	if ($meta=~/ $ename /) {
		open(EL, "$path_data/eperm/editall/$ename.perm");
		$editallArea = <EL>;
		close(EL);
		if (($editallArea=~/editall/g) || (($editallArea eq "") && ($meta=~/ $ename /))) {
			print "$bold EDITALL $unBold<br>\n";
		} else {
			if ($meta=~/ $ename /) {
				print "$bold CATEDITALL $unBold<br>\n";
			}
		}
	}

	#---Open List Of Metas
	open(META, "$path_data/dirman.gf");
	$meta = <META>;
	close(META);
	#---Close list

	if ($meta=~/ $ename /) {
		open(EL, "$path_data/eperm/meta/$ename.perm");
		$metaarea = <EL>;
		close(EL);
		if ($metaarea=~/meta/g)	{
			print "$bold META $unBold<br>\n";
		} else {
			print "$bold CATMOD $unBold<br>\n";
		}
	}

	#---Open List Of Roots
	open(ROOT, "$path_data/root.gf");
	$root = <ROOT>;
	close(ROOT);
	#---Close list

	if ($root=~/ $ename /) {
		print "$bold ROOT $unBold</br>\n";
	}

	print "$bold EDITOR $unBold</br>\n";

	return 1;
}


# Generates the HTML code in order to list the cats for a given editor
# Params: 1
# Param 1: the name of the editor
# Returns: 1 (always)

sub listCats
{
	my($name) = @_;

	print "<p>$bold$name $TS::TS_common_editsin$unBold</p>\n";
	open(EL, "$path_data/eperm/$name.perm");
	$ucat = <EL>;
	close(EL);
	print $bold;
	if ($ucat eq "") {
		$ucat = " ";
	}

	open(EL, "$path_data/pginfo/tble");
	$table = <EL>;
	close(EL);

	$uct = " ";
	$uct2 = "";
	$ind = 1;
	$subcats = 0;
	my @cCats;

	while ($uct ne $ucat) {
		$uct = $uct . substr($ucat, $ind, 1);
		$uct2 = $uct2 . substr($ucat, $ind, 1);
		if ($uct2 eq " ") {
			$uct2 = "";
		}
		++$ind;
		if (substr($ucat, $ind, 1) eq ";") {
			$uct3=$uct2;
			$uct2=~s/\>/: /g;
			$uct3=~s/\>/\//g;
			push(@cCats, "<li><a href=\"../$uct3\">$uct2</a></li>");
			$uct2 = "";
			$uct = $uct . substr($ucat, $ind, 1);
			++$ind;
		}
	}

	my($c, $d, $item);

	@cCats = sort {
		($c) = $a=~/<li><a href=\".*?\">(.*?)<\/a>/;
		($d) = $b=~/<li><a href=\".*?\">(.*?)<\/a>/;
		$c cmp $d;
	} (@cCats);

	foreach $item (@cCats) {
		print $item;
	}

	print "$unBold<br>";

	return 1;
}


# Show profile notes of an editor.
# Params: 1
# Param 1: the editorial account of the editor.

sub profilenote
{
	my($editor) = @_;
	my $enamel = $editor;

	open(USERS, "$path_data/logs/pnotes/$editor.note");
	my @notes = <USERS>;
	close(USERS);

	print "<H3>$TS::TS_logs_profilenotes:</H3>";
	print "<br><center>\n";

	open(USERS, "$path_data/inlist");
	$users = <USERS>;
	close(USERS);
	if ($users=~/ $enamel /) {
                print "<table cellSpacing=\"0\" cellPadding=\"4\" bgColor=\"#ff9999\" border=\"0\">\n";
                print "<tr bgColor=\"#ff00000\">\n<td><strong>$TS::TS_logs_removededitor</strong></td>\n</tr>\n<tr>\n";
                print "<tr><td> $TS::TS_logs_removereason";
                print "</td></tr></table><br><br>";
	}

	my $x = 0;
	my $colorHead = "unknown";
	my $colorBody = "unknown";

	foreach(@notes) {
		my @notedat = split(/\|/, $_);  

		$notedat[4]=~s/\((http:\/\/.*?)\)/<a href=\"$1\">$1<\/a>/g;
		#$notedat=~s/"(http:\/\/.*?)"/"<a href="$1">$1<\/a>"/g;

		if ($notedat[1] eq "green") {
			$colorHead = "#66cc66";
			$colorBody = "#ccffaa";
		}

	        if ($notedat[1] eq "yellow") {
			$colorHead = "#ffcc00";
			$colorBody = "#fff000";
	        }

	        if ($notedat[1] eq "red") {
			$colorHead = "#ff0000";
			$colorBody = "#ff9999";
	        }

	        if ($notedat[1] eq "purple") {
			$colorHead = "#aa99ff";
			$colorBody = "#ccccff";
		}

		if ($colorHead ne "unknown") {
			print <<END;
<table cellSpacing="0" cellPadding="4" bgcolor="$colorBody" border="0">
  <tr bgcolor="$colorHead">
    <td>
      <strong>
        $notedat[3]
      </strong>
    </td>
  </tr>
  <tr>
    <td>
      $notedat[4]
      <p>
        [<a href="profile.cgi?editor=$notedat[0]">$notedat[0]</a> $notedat[2]]
        <br>
        [<a href="pnote.cgi?editor=$editor&note=$x&act=mod">$TS::TS_common_update</a>] 
        [<a href="pnote.cgi?editor=$editor&note=$x&act=del">$TS::TS_common_delete</a>]
      </p>
    </td>
  </tr>
</table><br><br>
END
		}
		$x++;
	}

	print "<p><a href=\"pnote.cgi?editor=$enamel\">$TS::TS_logs_addnote</a>";

	print "</center>\n";

	return 1;
}


# Displays information about an editor, including his privs and his cats
# Params: 1
# Param 1: the name of the editor
# Returns: 1 (always)

sub editorInfo
{
	my($name) = @_;

	print "<h2>$TS::TS_common_editor: $name</h2>\n";
	print "<hr width=\"100%\">\n";
	print "$TS::TS_common_privs: <br>\n";
	listPrivs($name);

	if (($0 !~/dprofile/) && ($isMeta eq 1)) {
		print "<hr>";
		profilenote($name);
	}

	print "<hr width=\"100%\">\n";
	listCats($name);
	print "<hr width=\"100%\">\n";

	return 1;
}


return 1; 
