#************************************************************************
#
# The contents of this file are subject to the Mozilla Public License
# Version 1.1 (the "License"); you may not use this file except in
# compliance with the License. You may obtain a copy of the License at
# http://www.mozilla.org/MPL/
#
# Software distributed under the License is distributed on an "AS IS"
# basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
# License for the specific language governing rights and limitations
# under the License.
#
#
# The Original Code is Open-site.
#
# The Initial Developer of the Original Code is Open-site.org Website.
#
# Portions created by Open-site.org are Copyright (C) 2002.
# All Rights Reserved.
#
#************************************************************************


package Storage;

use Settings;

if ($sqluse == 1) {
	#Required for SQL access
	require ("$path_code/sql.pl");
}

# Retrieves data
# Params: at least 2
# Param 1: the name of the domain
# Param 2..n: the name of the variable
# Returns: the content retrieved

sub getData
{
	my $domain = $_[0];
	my $file;
	
	if ($domain eq "category") {
		my $cat = $_[1];
		my $section = $_[2];

		$file = "$path_sitedata/$cat.$section";
	} elsif ($domain eq "editor") {
		my $cat = $_[1];
		my $section = $_[2];

		$file = "$path_home/profiles/$cat.$section";
	} elsif ($domain eq "global") {
		my $cat = $_[1];

		$file = "$path_data/$cat";
	}

	if (-f $file) {
		open(F, $file);
		my @val = <F>;
		close(F);

		return join("", @val);
	}

	return "";
}


# Stores data
# Params: at least 3
# Param 1: the name of the category
# Param 2..n-1: the name of the variable
# Param 3: content to be set
# Returns: 1 (always)

sub setData
{
	my $domain = $_[0];
	
	if ($domain eq "category") {
		my $cat = $_[1];
		my $section = $_[2];
		my $val = $_[3];

		$cat=~s/[\n\r]//g;
		$section=~s/[\n\r]//g;
		
		open(FW, ">$path_sitedata/$cat.$section");
		print FW $val;
		close(FW);
	} elsif ($domain eq "editor") {
		my $cat = $_[1];
		my $section = $_[2];
		my $val = $_[3];
		
		if (!(-d "$path_home/profiles")) {
			mkdir("$path_home/profiles");
		}
		open(F, ">$path_home/profiles/$cat.$section");
		print F $val;
		close(F);
	} elsif ($domain eq "global") {
		my $cat = $_[1];
		my $val = $_[2];
		
		open(F, ">$path_data/$cat");
		print F $val;
		close(F);
	}
		
	return 1;
}


# Returns an ID with the next available edit ID and
#  increments this number with 1
# Params: 0
# Returns: the ID of the next available edit

sub logGetID
{
	if (!(-d "$path_home/edits")) {
		mkdir "$path_home/edits";
	}

	my $edits = 0;
	if (open(EL, "$path_home/edits/edit1")) {
		$edits = <EL>;
		close(EL);
		$edits=~s/[\n\r]//g;
	}
	
	if ($edits=~/^([0-9]+)$/) {
		$edits = $1;
	} else {
		print "Corruption Error in edit ID file.";
		exit();
	}

	my $totaledits = $edits + 1;
	# If writing will clobber the file, die with message
	if ($totaledits=~/^([0-9]+)$/) {
		open(LDATA2, ">$path_home/edits/edit1");
		print LDATA2 "$totaledits";
		close(LDATA2);
	} else {
		print "Error occurred while writing to log.";
		exit();
	}

	return $totaledits;
}


# Records the summary of a log entry in the suitable places and
#  allocates at the same time a valid ID
# Params: 3
# Param 1: the action performed (like "edit")
# Param 2: what was modified (like "section", "related");
# Param 3: the category where the edit happened
# Returns: the ID allocated to the log entry

sub logRecordSummary
{
	my($action, $what, $cat) = @_;
	my($lt, $totaledits);

	$lt = localtime;
	$totaledits = logGetID();

	if (!(-d "$path_data/logs")) {
		mkdir("$path_data/logs");
	}
	if (!(-d "$path_data/logs/rootlog")) {
		mkdir("$path_data/logs/rootlog");
	}
	open(TEXTFILE, ">>$path_data/logs/rootlog/comeditlog.log")||die "Could not append to edit log: $!";
	print TEXTFILE " ##!!## $ENV{REMOTE_USER} #!# ##!## $lt";
	print TEXTFILE " #!# ##!## $action #!# ##!## $what #!# ##!!!##";
	print TEXTFILE " $cat - $totaledits ##!!!!## \n";
	close(TEXTFILE);

	return $totaledits;	
}


# Makes a log entry
# Params: 4
# Param 1: the action performed (like "edit")
# Param 2: what was modified (like "section", "related");
# Param 3: the category where the edit happened
# Param 4: the content of the data, separated by \n
# Returns: 1 (always)

sub logEdit
{
	my($action, $what, $cat, $content, $oldcont) = @_;
	my($lt, $totaledits);

	$totaledits = logRecordSummary($action, $what, $cat);
	$lt = localtime;

	if ($sqluse eq 0) {
		my $ip = "";
		if (defined $ENV{REMOTE_ADDR}) {
			$ip = $ENV{REMOTE_ADDR};
		}
		open(TEXTFILE, ">$path_home/edits/$totaledits.log")||die "Could not open log file $totaledits.log: $!";
		print TEXTFILE "$ENV{REMOTE_USER}\n";
		print TEXTFILE "$ip\n";
		print TEXTFILE "$lt\n";
		print TEXTFILE "$cat\n";
		print TEXTFILE "$content";
		close(TEXTFILE);
	}

	if ($sqluse eq 1) {
		SQLConnect();

		$content=~s/\"/&quot\;/g;
        	$content=~s/\</&lt\;/g;
	        $content=~s/\>/&gt\;/g;
        	$content=~s/\'/&acute\;/g;

		my $sql = qq{ INSERT INTO edits
	                (edit, editor, cat, time, curcont, ip, oldcont)
        	        values
                	("$totaledits", "$ENV{REMOTE_USER}", "$cat", "$lt", "$content", "$ENV{REMOTE_ADDR}", "$oldcont")
		};

		SQLWrite($sql);

		SQLDisconnect();
	}

	return 1;
}


# Makes a meta log entry
# Params: 7
# Param 1: the editor who will have this added to their request log
# Param 2: the editor who preformed the action
# Param 3: the action preformed
# Param 4: the category or permission (if not needed, set to 0)
# Param 5: comments entered by the editor who preformed the action
# Param 6: set to 1 to hide the editor who preformed the action
# Param 7: set to 1 only log this in the meta log
# Returns: 1 (always)

sub logMetaEdit {
	if (!(-d "$path_data/logs")) {
		mkdir("$path_data/logs");
	}
	if (!(-d "$path_data/logs/rootlog")) {
		mkdir("$path_data/logs/rootlog");
	}

	my($username, $who, $action, $what, $reason, $hidden, $metaonly) = @_;
	if (!defined $metaonly) {
		$metaonly = "";
	}

	my($lt);

	$lt = localtime;
	if ($what ne 0) {
		$what = $what . ' - ';
	} else {
		$what = '';
	}

	if (!$metaonly) {
		open(TEXTFILE, ">>$path_data/logs/rootlog/areqeditlog.log");
		if ((defined $hidden) && ($hidden eq 1)) {
			print TEXTFILE " ##!!## $username #!# ##!## $lt #!# ##!## HIDDEN - $who #!# ##!## $action #!# ##!!!## $what $reason ##!!!!## \n";
	        } else {
			print TEXTFILE " ##!!## $username #!# ##!## $lt #!# ##!## $who #!# ##!## $action #!# ##!!!## $what $reason ##!!!!## \n";
		}
		close(TEXTFILE);
	}

	open(TEXTFILE, ">>$path_data/logs/rootlog/ametalog.log");
	print TEXTFILE " ##!!## $who #!# ##!## $lt #!# ##!## $username #!# ##!## $action #!# ##!!!## $what $reason ##!!!!## \n";
	close(TEXTFILE);

	return 1;
}



# Validates a file name and converts him in order to prevent attacks
# Params: 1
# Param 1: the name of the file
# Returns: the name of the file, converted after applying security measures

sub validateFileName
{
	my($fileName) = @_;
	
	if (defined $fileName) {
		$fileName=~s/\\/_/g;
		$fileName=~s/\//_/g;
		$fileName=~s/ /_/g;
		$fileName=~s/\`//g;
		$fileName=~s/\|//g;
		$fileName=~s/\;//g;
		$fileName=~s/<//g;

		$fileName=~/^(.*)$/;
		$fileName = $1;
	}

	return $fileName;
}


return 1;
