#************************************************************************
#
# The contents of this file are subject to the Mozilla Public License
# Version 1.1 (the "License"); you may not use this file except in
# compliance with the License. You may obtain a copy of the License at
# http://www.mozilla.org/MPL/
#
# Software distributed under the License is distributed on an "AS IS"
# basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
# License for the specific language governing rights and limitations
# under the License.
#
#
# The Original Code is Open-site.
#
# The Initial Developer of the Original Code is Open-site.org Website.
#
# Portions created by Open-site.org are Copyright (C) 2002.
# All Rights Reserved.
#
#************************************************************************


# This represents the UI - User Interface package.

package UI;

use base 'Exporter';

our @EXPORT = ('$bold', '$unBold');

use CGI;
use Settings;
use Storage;
use TS;

my $cgi = new CGI;

#Constants
$bold = "<strong>";
$unBold = "</strong>";

#Required for the color scheme
require ("$path_code/colors.pl");


# Formats a category in order to use the / sign instead of > and to
#  replace underscores with spaces
# Params: 1
# Param 1: the name of the category
# Returns: the category with another format

sub getNiceFormat
{
	my($cat) = @_;

	$cat =~s/>/\//g;
	$cat =~s/_/ /g;

	return $cat;
}


# Generates the CGI Header and HTML header for editing pages
# Params: 1 (optional)
# Param 1: a title to be displayed in the generated header.
# Returns: 1 (always)

sub writeHeaderCode
{
	my($title) = @_;
	if ((!defined $title) || ($title eq "")) {
		$title = "$HD_name";
	} else {
		$title = "$HD_name - $title";
	}
	print "Content-Type: text/html; charset=utf-8\n\n";
	print <<END;
<html>
<head>
<title>$title</title>
<meta http-equiv="Content-Type" content="text/html; charset=UTF-8">
<meta http-equiv="cache-control" content="no-cache">
<meta http-equiv="pragma" content="no-cache">
<meta http-equiv="expires" content="0">
</head>
<body text="$text[$currentskin]" vLink="$vlink[$currentskin]" aLink="$alink[$currentskin]" link="$link[$currentskin]" bgColor="$lightest[$currentskin]">
<center>
<table cellSpacing="0" cellPadding="3" width="100%" bgColor="$darkest[$currentskin]" border=0 style="border-collapse: collapse" bordercolor="#111111" height="36">
  <tbody>
  <tr bgcolor=$darkest[$currentskin]>
    <td vAlign="center" align="left" height="23" width="238">&nbsp;<font face="Arial, Helvetica, sans-serif" size="5" color="$lightest[$currentskin]">$HD_title</font></td>
    <td vAlign="center" align="left" height="23" width="530">&nbsp;</td></tr>
  <tr bgcolor=$light[$currentskin]>
    <td align="right" bgColor="$light[$currentskin]" height="1" width="90%">
    <p align="left">&nbsp;<font face="Arial, Helvetica, sans-serif" size="2">$HD_description</font></td>
    <td align="right" bgColor="$light[$currentskin]" height="1" width="530">$bold<a href="$path_on_server/">$TS::TS_common_home</a>$unBold</td></tr></tbody></table></center>
<p>
END
	#Check to see if the system is offline
	if (-f "$path_web/editors/suspend.txt") {
		open(OFFLINE, "$path_web/editors/suspend.txt");
		@offline = <OFFLINE>;
		close(OFFLINE);
		print <<END;
<pre>Open-site.org - $TS::TS_common_systemsuspended

$TS::TS_common_suspend1

$TS::TS_common_suspend2

$TS::TS_common_suspend3

The Open-site Staff.

---

$TS::TS_common_suspendroot $offline[0]
$TS::TS_common_suspendetr $offline[1]
$TS::TS_common_suspendreason $offline[2]</pre>
</body></html>
END
		exit(0);
	}

	#Check to see if the current user must accept a warning

	my $sw = 0;
	if (open(META, "$path_data/logs/warnlog/$ENV{REMOTE_USER}.sw")) {
		$sw = <META>;
		close(META);
	}

	if ((defined $sw) && ($sw=~/1/)) {
		print "<h2>$TS::TS_common_editor: $ENV{REMOTE_USER}</h2>\n";
		print <<END;
<hr width="100%">
<h1>$TS::TS_common_newwarning</h1><hr>
<table border="1" cellpadding="0" cellspacing="0" style="border-collapse: collapse" width="600" bgcolor="#FFA0A0"><tr><td width="600">
END
		open(INFILE, "$path_data/logs/warnlog/$ENV{REMOTE_USER}.log");
		@rlog = <INFILE>;
		close(INFILE);
		print "@rlog";

		print "</table> <br />";
		print <<END;
<form method="post" action="$path_on_server/editors/warnlog.cgi">
<p><input type="submit" value="Accept Warning" name="cmd"></p>
</form>
</body></html>
END
		writeFooterCode();
		exit(0);
	}

	return 1;
}


# Writes the HTML code in order to link back to the edit page
# Params: 1
# Param 1: $cat <-- name of the category to link to
# Returns: 1 (always)

sub writeEditLink
{
	my($cat) = @_;

	if (defined $cat) {
		my($ncat);

		$ncat = $cat;
		$ncat=~s/>/\//g;

		if ($ncat ne "") {
			print ("<p>$bold");
			print ("<a href=\"editcat.cgi?cat=$ncat\">");
			print ("$TS::TS_common_backediting");
			print ("</a>");
			print ("$unBold</p>");
		}
	}

	return 1;
}


# Displays the footer for an editing script
# Params: 1
# Param 1: the name of the category
# Returns: 1 (always)

sub writeScriptFooter
{
	my($cat) = @_;

	writeEditLink($cat);
	writeBackLink();
	writeFooterCode();

	return 1;
}


# Writes the HTML code required to display a link back to dashboard
# Params: 0
# Returns: 1 (always)

sub writeBackLink()
{
	print "<p>$bold<a href=\"./\">$TS::TS_common_backdash</a>$unBold</p>";
	return 1;
}


# Writes the footer HTML code for the editing pages
# Params: 0
# Returns: 1 (always)

sub writeFooterCode()
{
	print <<END;
  <p><table style="BORDER-COLLAPSE: collapse" borderColor=$darkest[$currentskin] cellSpacing="0" cellPadding="4" width="100%" border="1">
    <tr bgcolor=$darkest[$currentskin]>
      <td width="563" height="2">
      <font face="Arial, Helvetica, sans-serif" color="$lightest[$currentskin]" size="-2">
      Copyright &copy; $HD_name - using the <a href="http://open-site.org/code"><font color=\"$lightest[$currentskin]\">Open Site Code $OS_ver</font></a></font></td>
    </tr>
  </table></p>
END
	print "</body></html>";

	return 1;
}

sub editRedirect
{
	my($cat) = @_;
	
	if ((!defined($cat)) || ($cat eq "")) {
		my $cgi = new CGI;
		$cat = $cgi->param('cat');
	}
	
	my $chkqedit = "";
	my $fileLocation = "$path_data/misc/$ENV{REMOTE_USER}.qedit";
	if (-f $fileLocation) {
		open(TEXTFILE, $fileLocation);
		$chkqedit = <TEXTFILE>;
		close(TEXTFILE);
	}
	
	if ($chkqedit eq "on") {
		#print "<meta http-equiv=\"refresh\" content=\"1; URL=./editcat.cgi?cat=$cat\">";
		$ncat = getNiceFormat($cat);
		print "Status: 302 Moved\n";
		print "Location: ./editcat.cgi?cat=$ncat\n\n";
	}
}


# Shows an error
# Params: 4
# Param 1: The title (required for calling writeHeaderCode)
# Param 2: The error message that needs to be displayed.
# Param 3: The category where the error occured.
# Param 4: The URL for the back link.

sub showError
{
	my($title, $err, $errCat, $errURL) = @_;

	writeHeaderCode($title);
	print "<p>$err</p>";

	if (!(defined $errURL)) {
		$errURL = "";
	}

	if ($errURL ne "") {
		print "<a href=\"$errURL\">$TS::TS_common_back</a>";
	}

	writeScriptFooter($errCat);

	exit(0);
}


# Starts the form on a specific editing script
# Params: 2
# Param 1: the name of the category
# Param 2: the file where to post the data
# Returns: 1 (always)

sub writeStartForm
{
	my($cat, $action) = @_;

	if (!(defined $action)) {
		$action = "";
	}
	if ($action eq "") {
		print "<form method=\"post\">";
	} else {
		print "<form method=\"post\" action=\"$action\">";
	}

	print "<table border=\"0\" cellpadding=\"1\">";
	
	#writeItemForm("<strong>Description</strong>", "<strong>Data</strong>");

	writeHiddenForm("cat", $cat);

	return 1;
}

sub writeInputItemForm
{
	my($a, $b, $c, $d) = @_;

	if (!defined $d) {
		$d = "";
	}
	
	my $HTML = "<input type=\"$b\" name=\"$c\" value=\"$d\">";

	if ($b ne "hidden") {
		writeItemForm($a, $HTML);
	} else {
		print $HTML;
	}

	return 1;
}


sub writeItemForm
{
	my($a, $b) = @_;

	print "<tr bgcolor=\"#f0f0f0\">";

	if ($a ne "") {
		print "<td>$a:</td><td>$b";
	} else {
		print "<td colspan=\"2\" align=\"center\">$b";
	}

	print "</td></tr>";

	return 1;
}

# Generates the HTML in order to specify a hidden value inside a form
# Params: 2
# Param 1: The name of the variable to be introduced
# Param 2: The value of the variable
# Returns: 1 (always)

sub writeHiddenForm
{
	my($a, $b) = @_;

	writeInputItemForm("", "hidden", $a, $b);

	return 1;
}


# Generates the HTML in order to specify a checkbox
# Params: 3 or 4
# Param 1: The name of the variable to be introduced
# Param 2: The value of the variable
# Param 3: The text to place after the checkbox
# Param 4 (optional): "checked" to make default checked
# Returns: 1 (always)

sub writeCheckboxForm
{
	my($a, $b, $c, $d) = @_;
  
	if (lc $d ne "checked") {
		$d = "";
	}
	my $checkbox = "<input type=\"checkbox\" value=\"$b\" name=\"$a\" $d>";
	writeItemForm("", "$checkbox $c");
  
	return 1;
}


# Ends the form on a specific editing script
# Params: 2
# Param 1: (optional) The name of the button [submit]
# Param 2: (optional) The value of the button [$TS::TS_common_submit]
# Returns: 1 (always)

sub writeEndForm
{
	my($name, $val) = @_;

	if (!(defined $name)) {
		$name = "";
	}

	if ($name eq "") {
		$name = "submit";
	}

	if (!(defined $val)) {
		$val = "";
	}

	if ($val eq "") {
		$val = $TS::TS_common_submit;
	}

	writeInputItemForm("", "submit", $name, $val);

	print "</table>";
	print "</form>";

	return 1;
}


# Displays a comment for the current editing script and the name of
#  the category with nice formatting
# 
# Param 1: the name of the category
# Param 2: the title of the script
# Param 3: details / instructions for utilization
# Returns: 1 (always)

sub writeScriptHeader
{
	my($cat, $title, $comment) = @_;
	my($niceCat);


	if ($title ne "") {
		print "<h3>$title</h3>\n";
	}

	if (!(defined $niceCat)) {
		$niceCat = "";
	}
	if ($niceCat ne "") {
		$niceCat = getNiceFormat($cat);
		
		print "<p>$TS::TS_common_category: ";
		print "$bold$niceCat$unBold</p>\n";
	}

	if (!(defined $comment)) {
		$comment = "";
	}
	if ($comment ne "") {
		print "<p>$comment</p>\n";
	}

	return 1;
}


sub noHTML
{
	my($content) = @_;

	$content=~s/</&lt;/g;
	$content=~s/>/&gt;/g;

	return $content;
}


sub safeHTML
{
	my($content) = @_;

	if (defined $content) {
		$content=~s/<xmp>/&lt;xmp&gt;/g;
		$content=~s/<xml>/&lt;xml&gt;/g;
		$content=~s/<noscript>/&lt;noscript&gt;/g;
		$content=~s/<script>/&lt;script&gt;/g;
		$content=~s/<pre>/&lt;pre&gt;/g;
		$content=~s/<!--/&lt!--/g;
		$content=~s/-->/--&gt;/g;
	}

	return $content;
}


return 1;
