#!/usr/bin/perl -wT
#************************************************************************
#
# The contents of this file are subject to the Mozilla Public License
# Version 1.1 (the "License"); you may not use this file except in
# compliance with the License. You may obtain a copy of the License at
# http://www.mozilla.org/MPL/
#
# Software distributed under the License is distributed on an "AS IS"
# basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
# License for the specific language governing rights and limitations
# under the License.
#
#
# The Original Code is Open-site.
#
# The Initial Developer of the Original Code is Open-site.org Website.
#
# Portions created by Open-site.org are Copyright (C) 2002.
# All Rights Reserved.
#
#************************************************************************

use strict;
use CGI;

use lib '.';
use Include;
use Editor;
use Settings;
use TS;
use UI;

my($cgi) = new CGI;
my($action) = $cgi->param('action');
my $lt = localtime;

if (!(-d "$path_data/abuse")) {
        mkdir "$path_data/abuse";
}

if (!(defined $action)) {
	$action = "";
}

sub getText
{
	my($status, $items) = @_;

	my($text) = "";

	if (($status eq "\n") || ($status eq "") || ($status eq "\r") || ($status eq "New")) {
		$text = $TS::TS_abuse_statusnew;
	}

	if (($items > 5) && (($status eq "\n") || ($status eq "") || ($status eq "New"))) {
		$text = $TS::TS_abuse_discussed;
	}

	if ($text eq "") {
		$text = $status;
	}

	return $text;
}

sub getColor
{
	my($status, $items) = @_;

	$status=~s/\n//g;
	$status=~s/\r//g;
	$status=~s/New/#00ff00/;
	$status=~s/^$/#00ff00/;

	if ($items > 5) {
		$status=~s/#00ff00/#ffff00/;
	}

	if (!($status=~/#/)) {
		$status = "";
	}

	return $status;
}

if ($action eq "report") {
	# Display a form which allows editors to fill abuse reports

	UI::writeHeaderCode($TS::TS_abuse_title);
	# Editor::writeECode();

	print "<h2 align=\"center\">$TS::TS_abuse_report</h2>";

	UI::writeStartForm("", "abuse.cgi");
	UI::writeHiddenForm("action", "submit");
	UI::writeItemForm($TS::TS_abuse_from, "<a href=\"$path_on_server/editors/profile.cgi?editor=$ENV{REMOTE_USER}\">$ENV{REMOTE_USER}</a>");
	UI::writeInputItemForm($TS::TS_abuse_user, "text", "editor", "");
	UI::writeInputItemForm($TS::TS_abuse_cat, "text", "category", "");
	UI::writeItemForm($TS::TS_abuse_nature, "<textarea name=\"nature\" rows=\"8\" cols=\"60\"></textarea>");
	UI::writeEndForm();
}

if ($action eq "submit") {
	# Process the submission of a new abuse report

	my($ed) = $cgi->param('editor');
	my($cat) = $cgi->param('category');
	my($nature) = $cgi->param('nature');
	$nature=~s/\&/&amp;/g;
	$nature=~s/\|/&#124;/g;
	$nature=~s/\n/|/g;

	$ed = Editor::validateEditor($ed);
	$cat = Editor::validateCat($cat);

	open(COUNTER, "$path_data/abuse/counter");
	my($counter) = <COUNTER>;
	close(COUNTER);

	if ($counter eq "") {
		$counter = 0;
	}
	
	if ($counter=~/^([0-9]+)$/) {
		$counter = $1;
	} else {
		exit();
	}

	open(COUNTER, ">$path_data/abuse/counter");
	print COUNTER ++$counter;
	close(COUNTER);

	open(ABUSE, ">$path_data/abuse/$counter.info");
	print ABUSE "$ENV{REMOTE_USER}\n$lt\n$ed\n$cat\n$nature\nNew\n";
	close(ABUSE);

	UI::writeHeaderCode($TS::TS_abuse_title);
	# Editor::writeECode();

	print $TS::TS_abuse_sentokay;
}

if ($action eq "add") {
	# Process comments based on a existing abuse report

	UI::writeHeaderCode($TS::TS_abuse_title);
	# Editor::writeECode();

	Editor::restrictedMeta();

	my($do) = $cgi->param('do');
	my($id) = $cgi->param('id');
	my($nature) = $cgi->param('nature');
	$nature=~s/\&/&amp;/g;
	$nature=~s/\|/&#124;/g;
	$nature=~s/\n/|/g;
	
	if ($id=~/^([0-9]+)$/) {
		$id = $1;
	} else {
		exit();
	}

	open(ABUSE, ">>$path_data/abuse/$id.info");
	print ABUSE "$ENV{REMOTE_USER}|$lt|$nature\n";
	close(ABUSE);

	open(ABUSE, "$path_data/abuse/$id.info");
	my(@content) = <ABUSE>;
	close(ABUSE);

	if ($do == 0) {
		$content[5] = "\n";
	}

	if ($do == 1) {
		$content[5] = "No abuse found\n";
	}

	if ($do == 2) {
		$content[5] = "Abuse found\n";
	}

	if ($do == 3) {
		$content[5] = "Not enough proof\n";
	}

	open(ABUSE, ">$path_data/abuse/$id.info");
	print ABUSE join("", @content);
	close(ABUSE);

	print $TS::TS_abuse_addokay;
	print "<p><a href=\"abuse.cgi\">$TS::TS_abuse_backlist</a>";
}

if ($action eq "") {
	# Show an index with the current abuse reports

	UI::writeHeaderCode($TS::TS_abuse_title);
	# Editor::writeECode();

	Editor::restrictedMeta();

	print <<END;
<table border="0" width="100%"><tr bgcolor="#e0e0e0">
<td><strong>$TS::TS_abuse_status</strong></td>
<td><strong>$TS::TS_abuse_from</strong></td>
<td><strong>$TS::TS_abuse_when</strong></td>
<td><strong>$TS::TS_abuse_who</strong></td>
<td><strong>$TS::TS_abuse_where</strong></td>
</tr>
END

	my $counter = 0;
	if (-f "$path_data/abuse/counter") {
		open(COUNTER, "$path_data/abuse/counter");
		$counter = <COUNTER>;
		close(COUNTER);
	}
	
	if ($counter=~/^([0-9]+)$/) {
		$counter = $1;
	} else {
		exit();
	}

	my $color = "#e8e8e8";
	for (my $i = $counter; $i >= 1; $i--) {
		if (-f "$path_data/abuse/$i.info") {
			open(SUMMARY, "$path_data/abuse/$i.info");
			my(@content) = <SUMMARY>;
			close(SUMMARY);

			if ($color eq "#e8e8e8") {
				$color = "#f0f8f0";
			} else {
				$color = "#e8e8e8";
			}

			my($from) = $content[0];
			my($who) = $content[2];
			my($where) = $content[3];
			$where = UI::getNiceFormat($where);
			my($status) = $content[5];

			my($text) = getText($status, $#content);
			my($bgColor) = getColor($status, $#content);

			print "<tr bgcolor=\"$color\">";
			if ($bgColor ne "") {
				print "<td bgcolor=\"$bgColor\">";
			} else {
				print "<td>";
			}
			print <<END;
<a href="$path_on_server/editors/abuse.cgi?action=view&id=$i">$text</a></td>
<td><a href="$path_on_server/editors/profile.cgi?editor=$from">$from</a></td>
<td>$content[1]</td>
<td><a href="$path_on_server/editors/profile.cgi?editor=$who">$who</a></td>
<td><a href="$path_on_server/editors/editcat.cgi?cat=$where">$where</a></td>
</tr>
END
		}
	}

	print "</table>";
}

if ($action eq "view") {
	# View a specific abuse report

	UI::writeHeaderCode($TS::TS_abuse_title);
	# Editor::writeECode();

	Editor::restrictedMeta();

	my $id = $cgi->param('id');
	if (!defined $id) {
		$id = "";
	}
	
	if ($id eq "") {
		$id = 0;
	}

	if ($id=~/^([0-9]+)$/) {
		$id = $1;
	} else {
		exit();
	}

	if (!open(ABUSE, "$path_data/abuse/$id.info")) {
		print $TS::TS_abuse_notfound;
		UI::writeScriptFooter();
		exit(0);
	}

	my(@content) = <ABUSE>;
	close(ABUSE);

	my $from = $content[0];
	my $ed = $content[2];
	my $cat = $content[3];
	$cat = UI::getNiceFormat($cat);
	my $comments = $content[4];
	$comments=~s/\|/<br>/g;
	my $status = $content[5];

	my $text = getText($status, $#content);
	my $bgColor = getColor($status, $#content);

	print "<table border=\"0\" width=\"100%\">";
	print "<tr bgcolor=\"#f0f8f0\">";

	if ($bgColor ne "") {
		print "<td width=\"15%\" bgcolor=\"$bgColor\">";
	} else {
		print "<td width=\"15%\">";
	}

	print "$TS::TS_abuse_status:</td>";

	if ($bgColor ne "") {
		print "<td bgcolor=\"$bgColor\">";
	} else {
		print "<td>";
	}

	print <<END;
$text</td></tr>
<tr bgcolor="#e8e8e8"><td>$TS::TS_common_editor:</td>
<td><a href="$path_on_server/editors/profile.cgi?editor=$ed">$ed</a></td></tr>
<tr bgcolor="#f0f8f0"><td>$TS::TS_common_category:</td>
<td><a href="$path_on_server/editors/editcat.cgi?cat=$cat">$cat</a></td></tr>
<tr bgcolor="#e8e8e8" valign="top"><td>
<a href="$path_on_server/editors/profile.cgi?editor=$from">$from</a></td>
<td><small><img src="$path_on_server/posticon.gif"> item 0 - $content[1]</small>
<hr>$comments</td></tr>
END
	my($item) = 0;
	$bgColor = "#e8e8e8";
	for (my($x) = 6; $x <= $#content; $x++) {
		$item++;
		my($poster) = $content[$x];
		$poster=~s/^(.*?)\|.*$/$1/;
		my($date) = $content[$x];
		$date=~s/^.*?\|(.*?)\|.*$/$1/;
		my($nature) = $content[$x];
		$nature=~s/^.*?\|.*?\|(.*)$/$1/;
		$nature=~s/\|/<br>/g;

		if ($bgColor eq "#e8e8e8") {
			$bgColor = "#f0f8f0";
		} else {
			$bgColor = "#e8e8e8";
		}
		print "<tr bgcolor=\"$bgColor\" valign=\"top\"><td><a href=\"$path_on_server/editors/profile.cgi?editor=$poster\">$poster</a></td><td><small><img src=\"$path_on_server/posticon.gif\"> item $item - $date</small><hr>$nature</td></tr>";
	}
	print "</table>";

	if (($status eq "") || ($status eq "\n") || ($status eq "New\n")) {
		print <<END;
<p><form method="post" action="abuse.cgi">
<table bgcolor="#bbddff"><tr><td>Post comments:</td></tr>
<tr><td><textarea name="nature" cols="70" rows="10"></textarea></td></tr><tr><td>
<input name="do" type="radio" value="0" checked>$TS::TS_abuse_action0
<input name="do" type="radio" value="1">$TS::TS_abuse_action1
<input name="do" type="radio" value="2">$TS::TS_abuse_action2
<input name="do" type="radio" value="3">$TS::TS_abuse_action3
<input name="action" type="hidden" value="add">
<input name="id" type="hidden" value="$id"></td></tr>
<tr><td align="center">
<input type="submit" name="submit" value="$TS::TS_common_submit"></td></tr>
</table></form>
END
	}

	print "<p><a href=\"abuse.cgi\">$TS::TS_abuse_backlist</a>";
}

UI::writeScriptFooter();
