#!/usr/bin/perl
#************************************************************************
#
# The contents of this file are subject to the Mozilla Public License
# Version 1.1 (the "License"); you may not use this file except in
# compliance with the License. You may obtain a copy of the License at
# http://www.mozilla.org/MPL/
#
# Software distributed under the License is distributed on an "AS IS"
# basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
# License for the specific language governing rights and limitations
# under the License.
#
#
# The Original Code is Open-site.
#
# The Initial Developer of the Original Code is Open-site.org Website.
#
# Portions created by Open-site.org are Copyright (C) 2002.
# All Rights Reserved.
#
#************************************************************************


use strict;
use CGI;
use File::Copy;

use lib '.';
use Include;
use Common;
use Editor;
use Generate;
use Settings;
use Storage;
use TS;
use UI;

my $cgi = new CGI;

my($dcats);

# Initial path
my $cat = $cgi->param('cat');
my $z1 = "$cat";

# Final path
my $ncat = $cgi->param('ncat');
if ($ncat ne "") {
	$ncat = Editor::validateCat($ncat, 2);
}

my($z2) = "$ncat";

# Random fix
$ncat=~s/\//>/g;
$ncat=~s/\\/>/g;

my $act = $cgi->param('action');
my $zoldf = "$path_sitedata/$z1.html";
my $znewf = "$path_sitedata/$z2.html";
my $ok = "ok";

sub doFileMove
{
	my($f1, $f2, $suffix) = @_;
	my($oldf, $newf);

	$oldf = "$path_sitedata/$f1.$suffix";
	$newf = "$path_sitedata/$f2.$suffix";
	move($oldf, $newf);

	return 0;
}

sub doMove
{
	my($f1, $f2) = @_;
	my($oldf, $newf);

	# Introduce a redirect
	open(REDIR, ">$path_sitedata/$f1.redir");
	print REDIR "1\n$f2\n";
	close(REDIR);

	# Move files
	doFileMove($f1, $f2, "html");
	doFileMove($f1, $f2, "reviewed");
	doFileMove($f1, $f2, "unreviewed");
	doFileMove($f1, $f2, "tem");
	doFileMove($f1, $f2, "charter");
	doFileMove($f1, $f2, "pricat");
	doFileMove($f1, $f2, "catopt");
	doFileMove($f1, $f2, "ct");
	doFileMove($f1, $f2, "hist");
	doFileMove($f1, $f2, "tables");
	doFileMove($f1, $f2, "sections");
	doFileMove($f1, $f2, "usections");
	doFileMove($f1, $f2, "rel");
	doFileMove($f1, $f2, "altlangs");
	doFileMove($f1, $f2, "ed");
	doFileMove($f1, $f2, "based");
	doFileMove($f1, $f2, "symlinks");
	doFileMove($f1, $f2, "symlinksto");
	doFileMove($f1, $f2, "scl");
	doFileMove($f1, $f2, "seclinksto");


	# Move individual tables
	open(USERS, "$path_sitedata/$f2.tables");
	my($tt) = <USERS>;
	close(USERS);

	for (my($i) = "1"; $i <= $tt; $i++) {
		doFileMove($f1, $f2, "tbl$i");
	}

	# Move individual sections
	open(USERS, "$path_sitedata/$f2.sections");
	$tt = <USERS>;
	close(USERS);

	for (my($i) = "1"; $i <= $tt; $i++) {
		doFileMove($f1, $f2, "sct$i");
	}

	open(USERS, "$path_sitedata/$f2.usections");
	$tt = <USERS>;
	close(USERS);

	for (my($i) = "1"; $i <= $tt; $i++) {
		doFileMove($f1, $f2, "usct$i");
	}

	# Update @links
	open(LINKSTO, "$path_sitedata/$f1.symlinksto");
	while (<LINKSTO>) {
		my($line) = $_;
		chomp($line);
		my($linkedby) = split(/:/, $line);
		my $newfile = "";
		open(LINKS, "$path_sitedata/$linkedby.symlinks");
		while (<LINKS>) {
			my $linetwo = $_;
			chomp($linetwo);
			my ($title, $linkto) = split(/:/, $linetwo);
			if ($linkto eq $f1) {
				$newfile .= "$title:$f2\n";
			} else {
				$newfile .= "$title:$linkto\n";
			}
		}
		close(LINKS);
		open(LINKS, ">$path_sitedata/$linkedby.symlinks");
		print LINKS $newfile;
		close(LINKS);
	}
	close(LINKSTO);
# Update section links
	open(LINKSTO, "$path_sitedata/$f1.seclinksto");
	while (<LINKSTO>) {
		my($line) = $_;
		chomp($line);
		my($linkedby) = split(/:/, $line);
		my $newfile = "";
		open(LINKS, "$path_sitedata/$linkedby.scl");
		while (<LINKS>) {
			my $linetwo = $_;
			chomp($linetwo);
			my ($title, $linkto) = split(/:/, $linetwo);
			if ($linkto eq $f1) {
				$newfile .= "$title:$f2\n";
			} else {
				$newfile .= "$title:$linkto\n";
			}
		}
		close(LINKS);
		open(LINKS, ">$path_sitedata/$linkedby.scl");
		print LINKS $newfile;
		close(LINKS);
	}
	close(LINKSTO);
	# Move category titles
	$oldf = "$path_sitedata/items/titles/$f1.tlt";
	$newf = "$path_sitedata/items/titles/$f2.tlt";
	move($oldf, $newf);

	# Update editing permissions
	open(ED, "$path_sitedata/$f2.ed");
	my(@edi) = <ED>;
	close(ED);

	if (!($edi[0] eq "")) {
		my($inde) = 0;
		while (($edi[$inde] ne "") || ($edi[$inde+1] ne "")) {
			chomp($edi[$inde]);
			if ($edi[$inde] ne "") {
				open(EL, "$path_data/eperm/$edi[$inde].perm");
				my($lou) = <EL>;
				$lou=~s/ $f1; / $f2;  /g;
				close(EL);

				open(EL, ">$path_data/eperm/$edi[$inde].perm");
				print EL "$lou";
				close(EL);
			}
			$inde++;
		}
	}

	$dcats=~s/ $f1; / $f2; /g;

	Generate::updatePublicSide($f1);
	Generate::updatePublicSide($f2);
}

Editor::restrictedEditall();

open(USERS, "$path_sitedata/cats.lst");
$dcats = <USERS>;
close(USERS);

my($backLink) = "";

if ($act ne "") {
	$cat = Editor::validateCat($cat);
	my($f1) = "$cat";
	$f1 = Editor::validateCat($f1);

	$ncat = Editor::validateCat($ncat, 0);
	my($f2) = "$ncat";
	$f2 = Editor::validateCat($f2, 0);

	UI::writeHeaderCode("Category Rename");
	Editor::writeECode();

	if (Editor::testCATMVPrivs($cat) != 1) {
		printf "Error: you don\'t have the required privs in the target category.";
		UI::writeScriptFooter();
		exit(0);
	}

	if (Editor::testCATMVPrivs($ncat) != 1) {
		printf "Error: you don\'t have the required privs in the destination category.";
		UI::writeScriptFooter();
		exit(0);
	}

	doMove($f1, $f2);
	my $nf1 = UI::getNiceFormat($f1);
	my $nf2 = UI::getNiceFormat($f2);
	print "<p>$bold$nf1$unBold ==> $bold$nf2$unBold - <font color=\"green\">$TS::TS_common_done.</font>.</p>";

	my($lt);
	$lt  = localtime;

	open(FIL, ">>$path_data/logs/rootlog/catmv.log");
	print FIL "## $lt ## $ENV{REMOTE_USER} ## $f1 ## $f2 ##\n";
	close(FIL);

	# Update the counters for the parent categories
	$f1=~/^(.*)>[^>]*$/;
	my $pf1 = $1;
	$f2=~/^(.*)>[^>]*$/;
	my $pf2 = $1;

	$pf1=~s/\//>/g;
	$pf2=~s/\//>/g;

	if (($pf1 ne "") && ($pf2 ne "") && ($pf1 ne $pf2)) {
		my $noSections = Storage::getData('category', $f2, "reviewed");
		
		if ($noSections eq "") {
			$noSections = 0;
		}
		Common::updateCounter($pf1, "reviewed", -1 * $noSections);
		Common::updateCounter($pf2, "reviewed",  1 * $noSections);

		my $noSections = Storage::getData('category', $f2, "unreviewed");
		if ($noSections eq "") {
			$noSections = 0;
		}
		Common::updateCounter($pf1, "unreviewed", -1 * $noSections);
		Common::updateCounter($pf2, "unreviewed",  1 * $noSections);
	}

	my($g1, $g2, $ng1, $ng2);    

	while ($dcats=~/$f1(>[^;]*);/g) {
		$g1 = $f1 . $1;
		$g2 = $f2 . $1;
		doMove($g1, $g2);
		$ng1 = UI::getNiceFormat($g1);
		$ng2 = UI::getNiceFormat($g2);
		print "<p>$bold$ng1$unBold ==> $bold$ng2$unBold - <font color=\"green\">$TS::TS_common_done.</font>.</p>";
	}

	open(EL, ">$path_sitedata/cats.lst");
	print EL "$dcats";
	close(EL);

	print $TS::TS_catmv_catdone;
	$backLink = $f2;
} else {
	UI::writeHeaderCode("Category Rename");
	Editor::writeECode();

	print <<END;
<form action="catmv.cgi" method="POST">
<center>
<table border="0" width="80%" bgcolor="#F0F0DF">
<tr>
  <td>
  $TS::TS_catmv_info
  </td>
</tr>
</table>

<table bgcolor="#cccccc" border="0" cellspacing="0" cellpadding="5" width="80%">
<tr>
  <td>$bold$TS::TS_catmv_movefrom$unBold</td>
  <td>
<input type="text" name="cat" size="40" value="$cat">
</td>
</tr>
<tr>
  <td>$bold$TS::TS_catmv_to$unBold</td>
  <td>
<input type="text" name="ncat" size="40">

  </td>
</tr>
</table>

<input type="submit" name="action" value="$TS::TS_common_submit">

</form>
END
}

UI::writeScriptFooter($backLink);
