#!/usr/bin/perl
#************************************************************************
#
# The contents of this file are subject to the Mozilla Public License
# Version 1.1 (the "License"); you may not use this file except in
# compliance with the License. You may obtain a copy of the License at
# http://www.mozilla.org/MPL/
#
# Software distributed under the License is distributed on an "AS IS"
# basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
# License for the specific language governing rights and limitations
# under the License.
#
#
# The Original Code is Open-site.
#
# The Initial Developer of the Original Code is Open-site.org Website.
#
# Portions created by Open-site.org are Copyright (C) 2002.
# All Rights Reserved.
#
#************************************************************************


use strict;
use CGI;

use lib '.';
use Include;
use Editor;
use Settings;
use Storage;
use TS;
use UI;

my $cgi = new CGI;

UI::writeHeaderCode("Generate a new RDF");
Editor::writeECode();
Editor::restrictedRoot();

our $id = 0;
my ($rellink, $link, $linkto);

open(DCATS, "$path_sitedata/cats.lst");
my $ucat = <DCATS>;
close(DCATS);

our @ccats = split(";", $ucat);

sub generateRDF {
	open(FLOW, ">$path_data/code/bin/rdf.flow");
	print FLOW $id . "\|" . $#ccats . "\n";
	close(FLOW);

	my $cat = $_[0];
	my $spattern;
	my $nformat = $cat;
	my $title;
	$nformat=~s/>/\//g;
	if ($cat eq "") {
		print RDF "<Topic r:id=\"Top\">\n";
	} else {
		print RDF "<Topic r:id=\"Top/$nformat\">\n";
	}
	$id++;
	print RDF "  <tag catid=\"$id\"/>\n";
	if ($cat eq "") {
		print RDF "  <d:Title>Top</d:Title>\n";
	} else {
		open(INFILE, "$path_sitedata/items/titles/$cat.tlt");
		$title = <INFILE>;
		close(INFILE);

		if ($title eq "") {
			$title = $cat;
			if ($title=~/.*>([^>]*)/) {
				$title = $1;
			}
		}

		print RDF "  <d:Title>$title</d:Title>\n";
	}

	$spattern = $cat . ">";

	if ($spattern eq ">") {
		$spattern = "";
	}

	my $ucat;
	open(DCATS, "$path_sitedata/cats.lst");
	$ucat = <DCATS>;
	close(DCATS);

	while ($ucat=~/ ($spattern[^>;]*);/g) {
		my $found = $1;
		$found=~s/>/\//g;
		print RDF "  <narrow r:resource=\"Top/$found\"/>\n";
	}

	open(RELATED, "$path_sitedata/$cat.rel");
	my @rel = <RELATED>;
	close(RELATED);
	foreach $rellink (@rel) {
		$rellink=~s/\r//g;
		$rellink=~s/>/\//g;
		chomp($rellink);
		print RDF "  <related r:resource=\"Top/$rellink\"/>\n";
	}

	open(ALTLANG, "$path_sitedata/$cat.altlangs");
	my @rel = <ALTLANG>;
	close(ALTLANG);
	foreach $rellink (@rel) {
		$rellink=~s/\r//g;
		$rellink=~s/>/\//g;
		chomp($rellink);
		print RDF "  <altlang r:resource=\"Top/$rellink\"/>\n";
	}

	open(SYMLINKS, "$path_sitedata/$cat.symlinks");
	my @links = <SYMLINKS>;
	close(SYMLINKS);
	chomp(@links);
	foreach $link (@links) {
		($title, $linkto) = split(/:/, $link);
		$linkto=~s/>/\//g;
		print RDF "  <symbolic r:resource=\"$title:Top/$linkto\"/>\n";
	}

	print RDF "</Topic>\n\n";

	foreach $link (@links) {
		($title, $linkto) = split(/:/, $link);
		$linkto=~s/>/\//g;
		print RDF <<END;
<Alias r:id="$title:Top/$linkto">
  <d:Title>$title</d:Title>
  <Target r:resource="Top/$linkto"/>
</Alias>

END
	}

	while ($ucat=~/ ($spattern[^>;]*);/g) {
		$cat = $1;
		if (!($cat=~/^Test\>/)) {
			generateRDF($cat);
		}
	}
}

open(RDF, ">$path_web/rdf/structure.rdf");
print RDF <<END;
<RDF xmlns:r="http://www.w3.org/TR/RDF/"
     xmlns:d="http://purl.org/dc/elements/1.0/"  
     xmlns="http://directory.mozilla.org/rdf">

END

open(FLOW, ">$path_data/code/bin/rdf.start");
print FLOW time;
close(FLOW);

print "<p>Starting the process of RDF generation - do not push the stop button in your browser while the RDF is been generated.</p><p>Writing RDF file... in progress...</p>";
generateRDF("");

print RDF "\n</RDF>";

close(RDF);

open(FLOW, ">$path_data/code/bin/rdf.flow");
print FLOW $#ccats . "\|" . $#ccats . "\n";
close(FLOW);

open(FLOW, ">$path_data/code/bin/rdf.stop");
print FLOW time;
close(FLOW);

print "<p>File generated. A new structure RDF has been generated at /rdf/structure.rdf</p>";

UI::writeScriptFooter();
