#!/usr/bin/perl
#************************************************************************
#
# The contents of this file are subject to the Mozilla Public License
# Version 1.1 (the "License"); you may not use this file except in
# compliance with the License. You may obtain a copy of the License at
# http://www.mozilla.org/MPL/
#
# Software distributed under the License is distributed on an "AS IS"
# basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
# License for the specific language governing rights and limitations
# under the License.
#
#
# The Original Code is Open-site.
#
# The Initial Developer of the Original Code is Open-site.org Website.
#
# Portions created by Open-site.org are Copyright (C) 2002.
# All Rights Reserved.
#
#************************************************************************


use strict;
use CGI;
use File::Copy;

use lib '.';
use Include;
use Editor;
use EditorProfile;
use Forum;
use Logs;
use Settings;
use Storage;
use TS;
use UI;

if (!(-d "$path_data/rnapps")) {
	mkdir("$path_data/rnapps");
}
if (!(-d "$path_data/rjnapps")) {
        mkdir("$path_data/rjnapps");
}
if (!(-d "$path_data/oldperm")) {
        mkdir("$path_data/oldperm");
}

my $currenteditor = Editor::currentUser();

sub header
{
	UI::writeHeaderCode($TS::TS_reqedit_title);
	Editor::writeECode();
	Editor::restrictedMeta();
}

sub tableHeader
{
	my($cat) = @_;
	print <<END;
<table cellpadding="2" cellspacing="2" border="1">
  <tbody>
    <tr>
      <th>
        $TS::TS_common_editor
      </th>
      <th>
        $cat
      </th>
      <th>
        $TS::TS_reqedit_subtime
      </th>
    </tr>
END
}

sub displayIt(@content, $startWith)
{
	my ($x, @rapp) = @_;

	while ($x < $#rapp) {
		$x = $x + 1;
		print "$rapp[$x] <br>\n"
	}
}

sub checkEmail {
	my ($email) = @_;
	my @emails;
	my $x = 0;
	my $return = 1;
	opendir(DIR, "$path_data/misc");
	my @edits = readdir(DIR);
	closedir(DIR);

	chomp(@edits);
	foreach (@edits) {
		if ($_=~/.eaddr/) {	
			$_=~s/.eaddr//g;
			$emails[$x] = Editor::getEmail($_) . "\|" . $_;
			$x++;
		}
	}

	foreach(@emails) {
		my @split = split(/\|/, $_);
		if ($email eq $split[0]) {
			$return = $TS::TS_reqedit_erremail . ": " . "<a href=\"./profile.cgi?editor=$split[1]\">$split[0]</a>";
		}
	}

	return $return;
}


sub listCatWithLinks
{
	my($cat) = @_;

	my $ct = "";
	my $ct2 = "";
	my $ind = 0;
	my $ct22;

	while (($ct ne $cat) && ($ind < 200)) {
		$ct = $ct . substr($cat, $ind, 1);
		$ct2 = $ct2 . substr($cat, $ind, 1);
		++$ind;
		if ((substr($cat, $ind, 1) eq ">") || (substr($cat, $ind, 1) eq "/")) {
			my $rr = $ct;
			$rr=~s/>/\//g;
			$ct22 = $ct2;
			$ct22=~s/_/ /g;
			print "<a href=\"$path_on_server/editors/editcat.cgi?cat=$rr\">$ct22</a>: ";
			$ct2 = "";
			$ct = $ct . substr($cat, $ind, 1);
			++$ind;
		}
	}
	$ct=~s/>/\//g;
	$ct22 = $ct2;
	$ct22=~s/_/ /g;
	print "<a href=\"$path_on_server/editors/editcat.cgi?cat=$ct\">$ct22</a>";

	return 1;
}

sub generateFooter
{
	my($review, $app) = @_;

	if (($review ne "") && ($app ne "")) {
		if ($review eq "newapps") {
			print "<p>$bold<a href=\"reqedit.cgi?review=newapps\">$TS::TS_reqedit_rnewapps</a>$unBold</p>";
		}
		if ($review eq "newperm") {
			print "<p>$bold<a href=\"reqedit.cgi?review=newperms\">$TS::TS_reqedit_rnewperm</a>$unBold</p>";
		}
		if ($review eq "reinstate") {
			print "<p>$bold<a href=\"reqedit.cgi?review=reinstate\">$TS::TS_reqedit_rreinst</a>$unBold</p>";
		}
	}

	if ($review eq "") {
		print <<END;
<ul>
  <li><a href="reqedit.cgi?review=newapps">$TS::TS_reqedit_rnewapps</a></li>
  <li><a href="reqedit.cgi?review=newperms">$TS::TS_reqedit_rnewperm</a></li>
  <li><a href="reqedit.cgi?review=reinstate">$TS::TS_reqedit_rreinst</a></li>
</ul>
END
	} else {
		print "<p>$bold<a href=\"./reqedit.cgi\">$TS::TS_reqedit_reqindex</a>$unBold</p>";
	}

	UI::writeScriptFooter();
}


sub getContent
{
	my ($file) = @_;

	open(FILE, $file);
	my @content = <FILE>;
	close(FILE);

	return @content;
}


sub writeHTMLHeader
{
	my($title) = @_;

	print <<END_Q;
<table border="1" cellspacing="1" style="border-collapse: collapse" bordercolor="$UI::dark[$UI::currentskin]" width="100%" id="AutoNumber1" bgcolor="$UI::dark[$UI::currentskin]">
<tr>
<td width="100%"><font size="5" color="$UI::light[$UI::currentskin]">$title</font></td>
</tr>
<tr>
<td width="100%" bgcolor="$UI::box[$UI::currentskin]">
END_Q
}

sub generateCommonHTML
{
	my($app, $ddcat, $review2) = @_;
	my $dcat = $ddcat;
	$dcat=~s/ /_/g;

	print <<END;
<tr>
    <td width="100%" bgcolor="$UI::box[$UI::currentskin]">
END

	Logs::GenReqNotes($app);
	print "<br>";
	AddNoteArea($app, $ddcat);

	print <<END;
</td></tr>
<tr>
    <td width="100%" bgcolor="$UI::box[$UI::currentskin]">

    <form method="POST" action="reqedit.cgi">
    $TS::TS_reqedit_comments:<br>
	<textarea name="comments" rows="5" cols="70"></textarea>
</td></tr>
END
	if ($ddcat ne "reinstate") {
		print <<END;
<tr><td width="100%" bgcolor="$UI::box[$UI::currentskin]">$TS::TS_common_category:
<input type="text" name="modcat" value="$dcat" size="80"></td></tr>
END
	}

	print <<END;
<tr><td width="100%" bgcolor="$UI::box[$UI::currentskin]">
    <input type="hidden" name="app" value="$app">
      <input type="hidden" name="review" value="$review2">
      <select name="cmd">
      <option></option>
      <option>Accept</option>
      <option>Decline</option>
      </select>
      <input type="submit" value="$TS::TS_common_submit">
    </form></td></tr>
END
}


sub getForumLink
{
	# $type can be "napps", "nperms" or "nrins"
	my ($app, $editor, $ddcat, $type) = @_;

	my ($post, $forumlink, @posts);
	my $goodpost = "";

	#Get the date and time of this app
	my ($d, $d, $d, $d, $d, $d, $d, $d, $d, $apptime) = stat("$path_data/$type/$app.req");

	my $path = $Forum::boardsdir;
	$path=~s/\./$YaBB_path/g;

	@posts = getContent("$path/metaap.txt");

	chomp(@posts);
	foreach $post (@posts) {
		my($posttime, $subject) = split(/\|/, $post);
		if ($subject=~/$apptime: $editor/) {
			$goodpost = $posttime;
		}
	}

	if ($goodpost ne "") {
		$forumlink = "<a href=\"$Forum::boardurl/YaBB.cgi?board=metaap;action=display;num=$goodpost;start=0\"><i>$TS::TS_reqedit_readforumthread</i></a>";
	} else {
		$forumlink = "<a href=\"$Forum::boardurl/YaBB.cgi?board=metaap;action=post;title=Start+new+topic;newsubject=Request+$apptime:+$editor+($ddcat)\">$TS::TS_reqedit_startforumthread</a>";
	}

	return $forumlink;
}

sub trim
{
	my(@trim) = @_;

	for (my $d = 0; $d <= $#trim; $d++) {
		$trim[$d]=~s/\n//g;
	}

	return @trim;
}

#Generate note addition area 
sub AddNoteArea
{
	my($app, $tynote) = @_;

	my($cgi) = new CGI;
	my($review) = $cgi->param('review');

	print "<font size=\"+1\">$TS::TS_logs_addreqn:</font>";
	UI::writeStartForm("", "reqedit.cgi");       
	UI::writeHiddenForm("cmd", "post");
	UI::writeHiddenForm("type", "$tynote");
	UI::writeHiddenForm("miscre", "$review");
	UI::writeHiddenForm("app", "$app");
	UI::writeItemForm("", "<textarea name=\"note\" rows=\"3\" cols=\"30\"></textarea>");
	UI::writeEndForm();
}

sub testEmpty
{
	my($text) = @_;

	if ($text eq "") {
		print "$TS::TS_reqedit_ianiq";
		exit(0);
	}
}

sub sendEmail
{
	my($from, $to, $subject, @content) = @_;

	open(SENDMAIL, "| $path_sendmail") || die "Unable to open sendmail";
	print SENDMAIL <<END_MAIL;
From: $from
To: $to
Subject: $subject

@content
END_MAIL
	close(SENDMAIL);
}


sub checkAlreadyEditor
{
	my($username, $review, $app) = @_;

	my $user = Storage::getData("global", "elist");
	$user .= " " . Storage::getData("global", "inlist");

	if ($user=~/ $username /) {
		print $TS::TS_reqedit_edexist;
		print "<br><a href=\"./reqedit.cgi?review=remdup&app=$app\">$TS::TS_reqedit_remdup</a>" . "</table>";
		generateFooter($review, $app);
		exit(0);
	}
}


my($cgi) = new CGI;

our($review) = $cgi->param('review');
my($app) = $cgi->param('app');
my($cmd) = $cgi->param('cmd');
my($note) = $cgi->param('note');
my($miscre) = $cgi->param('miscre');
my(@comments) = $cgi->param('comments');
my($type) = $cgi->param('type');
my $lt = localtime;

my @rapp = trim(getContent("$path_data/napps/$app.req"));
my @rinstateapp = trim(getContent("$path_data/nrins/$app.req"));
my @rapp2 = trim(getContent("$path_data/nperms/$app.req"));
my $lt = localtime;


#Clean Duplicate Application
if (($review eq "remdup") && ($app ne ""))
{
        UI::writeHeaderCode("Editor Requests");
        Editor::writeECode();

	my $user = Storage::getData("global", "elist");
	$user .= " " . Storage::getData("global", "inlist");

        if ($user=~/ $rapp[1] /) {
		unlink("$path_data/napps/$app.req");
                generateFooter($review, $app);
                exit(0);
        }
}

#Add a note
if (($cmd eq "post") && ($app ne "")) {
	UI::writeHeaderCode("Editor Requests");
	Editor::writeECode();

	Editor::restrictedMeta();

	if (($rapp[1] eq "") && ($rinstateapp[1] eq "") && ($rapp2[1] eq "")) {
  		print $TS::TS_reqedit_ianiq;
	} else {
		$note=~s/\n//g;
		$note=~s/\|/-/g;

		open(LOG, ">>$path_data/logs/rootlog/rnotes.log");
		print LOG "\n$app|$type|$lt|$ENV{REMOTE_USER}|$note|$rapp2[1]$rapp[1]$rinstateapp[0] ";
		close(LOG);

		print "$TS::TS_reqedit_reqadded<br><br>";		
		print "<a href=\"./reqedit.cgi?review=$miscre&app=$app\">$TS::TS_reqedit_backtr</a>";
	}
	UI::writeScriptFooter();
	exit(0);
}


#Decline NewApp Request
if (($cmd eq "Decline") && ($app ne "") && ($review eq "newapps")) {
	header();
	Editor::catmodPriv($rapp[0]);
	testEmpty($rapp[1]);

	my @decletter = getContent("$path_data/declineletter.txt");

	sendEmail("noreply\@$HD_domain", $rapp[2], "$HD_name Application",
	  "Dear $rapp[1]\n @decletter\n\n Additional Comments From Reviewer:\n @comments");

	Storage::logMetaEdit($rapp[1],$currenteditor,'decline',0,"NewApp: $rapp[1] declined. -$app-",0,1);

	print "$TS::TS_reqedit_ad<br>Auto email sent.";

	#unlink("$path_data/napps/$app.req");
	move("$path_data/napps/$app.req", "$path_data/rjnapps/$app.req");
}

#Decline Reinstatement Request

if (($cmd eq "Decline") && ($app ne "") && ($review eq "reinstate")) {
	header();
	Editor::catmodPriv($rapp[0]);
	testEmpty($rinstateapp[0]);

	sendEmail("noreply\@$HD_domain", $rinstateapp[1], "$HD_name Reinstatement Request",
		@comments);
	
	Storage::logMetaEdit($rinstateapp[0],$currenteditor,'decline',0,"Reinstate: $rinstateapp[0] declined. -$app-",0,1);

	print "Application declined.<br> E-mail sent.";

	move("$path_data/nrins/$app.req", "$path_data/rjnapps/$app.req");
}

#Decline NewPerm Request

if (($cmd eq "Decline") && ($app ne "") && ($review eq "newperms")) {
	header();
	Editor::catmodPriv($rapp2[0]);
	testEmpty($rapp2[1]);

	Storage::logMetaEdit($rapp2[1],$currenteditor,'decline',0,$rapp2[0]);

	#print "Request declined.";

        open(FROM, "$path_data/misc/$rapp2[1].eaddr");
        my $fromeaddr = <FROM>;
        close(FROM);

	sendEmail("noreply\@$HD_domain", $fromeaddr, "$HD_name Permission Request", @comments);

	print "$TS::TS_reqedit_reqaps<br>";

	open(EL, "$path_data/oldperm/edit1");
	my $edits = <EL>;
	close(EL);

	my $totaledits = $edits + 1;

	open(LDATA2, ">$path_data/oldperm/edit1");
	print LDATA2 "$totaledits";
	close(LDATA2);

	move("$path_data/nperms/$app.req", "$path_data/oldperm/$totaledits-$rapp2[1]-$totaledits.req");
}

#Accept NewApp Request

if (($cmd eq "Accept") && ($app ne "") && ($review eq "newapps")) {
	my $ncat = $cgi->param('modcat');
	if ($ncat ne "") {
		$rapp[0] = $ncat;
	}

	$rapp[0] = Editor::validateCat($rapp[0]);

	header();
	Editor::catmodPriv($rapp[0]);
	testEmpty($rapp[1]);

	checkAlreadyEditor($rapp[1], $review, $app);

	Editor::setPassword($rapp[1], $rapp[3]);
	open(EL, ">>$path_data/elist");
	print EL "$rapp[1] ";
	close(EL);

	open(EL, ">>$path_data/eperm/$rapp[1].perm");
	print EL " Bookmarks>$rapp[1]; $rapp[0]; ";
	close(EL);

	open(EL, ">$path_sitedata/Bookmarks>$rapp[1].html");
	print EL "Bookmarks - $rapp[1] .";
	close(EL);

	open(EL4, ">>$path_sitedata/cats.lst");
	print EL4 "Bookmarks>$rapp[1]; ";
	close(EL4);

	open(TEXTFILE, ">>$path_sitedata/Bookmarks>$rapp[1].ed");
	print TEXTFILE "$rapp[1]\n";
	close(TEXTFILE);

	open(TEXTFILE, ">>$path_sitedata/$rapp[0].ed");
	print TEXTFILE "$rapp[1]\n";
	close(TEXTFILE);

	# Forum Code
	my @data =<<DATA;
$rapp[3]
$rapp[1]
$rapp[1]\@editor.com
$rapp[1]
username.com
-$rapp[1]
0
EDITOR

hmm
hmm
Male
Hi
blank.gif
YaBB Admin Land
Home?
1/1/1
1



DATA

	if ($YaBB_support == 1) {
		open(EL, ">$Forum::memberdir/$rapp[1].dat");
		print EL "@data";
		close(EL);

		open(EL, ">>$Forum::memberdir/memberlist.txt");
		print EL "$rapp[1]\n";
		close(EL);
	}

	open(TEXTFILE, ">$path_data/misc/$rapp[1].eaddr");
	print TEXTFILE "$rapp[2]\n";
	close(TEXTFILE);

	my @accletter = getContent("$path_data/acceptletter.txt");

	sendEmail("noreply\@$HD_domain", $rapp[2], "$HD_name Application", <<END);
Dear $rapp[1],

Thank you for applying to become an editor at Open Site.
We are pleased to inform you that your application has been successful.
Please take a moment to read through this email completely, as it contains
important information that you should read.

Your login details are:

Username: $rapp[1]
Password: $rapp[3]


@accletter

Additional Comments From Reviewer:
@comments

END
	print "Application accepted. <br>Auto email sent. <br><br>";  #"<br><br>Username: $rapp[1]<br>Password: $rapp[3]<br>Email: $rapp[2]<br><br>Be sure to write this editor and email them their username/password and a copy of the guidelines.<br><br>";

	Storage::logMetaEdit($rapp[1], $currenteditor, 'join', 0, $rapp[0]);

	move("$path_data/napps/$app.req", "$path_data/rnapps/$rapp[1].req");
}

#Accept Reinstatement Request

if (($cmd eq "Accept") && ($app ne "") && ($review eq "reinstate")) {
	header();
	$rinstateapp[0]=~s/ //g;

	Editor::catmodPriv($rapp[0]);
	testEmpty($rinstateapp[0]);

	my $users = Storage::getData("global", "elist");

	if ($users=~/ $rinstateapp[0] /) {
		print $TS::TS_reqedit_activebug;
		exit(0);
	}

	open(EL, ">>$path_data/elist");
	print EL "$rinstateapp[0] ";
	close(EL);

	open(EL, "$path_data/inlist");
	my $lou2 = <EL>;
	$lou2=~s/ $rinstateapp[0] / /g;
	close(EL);
	open(EL2, ">$path_data/inlist");
	print EL2 "$lou2";
	close(EL2);

	Storage::logMetaEdit($rinstateapp[0],$currenteditor,'reinstate',0,'reinstate queue');

	sendEmail("noreply\@$HD_domain", $rinstateapp[1], "$HD_name Reinstatement Request", @comments);

	print "Application accepted.<br> E-mail sent.";

	move("$path_data/nrins/$app.req", "$path_data/rjnapps/$app.req");
}


#Accept NewPerm Request

if (($cmd eq "Accept") && ($app ne "") && ($review eq "newperms")) {
	my $ncat = $cgi->param('modcat');
	if ($ncat ne "") {
		$rapp2[0] = $ncat;
	}

	$rapp2[0] = Editor::validateCat($rapp2[0]);
	header();

	Editor::catmodPriv($rapp2[0]);
	testEmpty($rapp2[1]);

	open(EL, ">>$path_data/eperm/$rapp2[1].perm");
	print EL " $rapp2[0]; ";
	close(EL);
	print "$TS::TS_reqedit_cataccept<br><br>";

	open(TEXTFILE, ">>$path_sitedata/$rapp2[0].ed"); 
	print TEXTFILE "$rapp2[1]\n"; 
	close(TEXTFILE);

	Storage::logMetaEdit($rapp2[1],$currenteditor,'accept',0,$rapp2[0]);

        open(FROM, "$path_data/misc/$rapp2[1].eaddr");
        my $fromeaddr = <FROM>;
        close(FROM);

	sendEmail("noreply\@$HD_domain", $fromeaddr, "$HD_name Permission Request", @comments);

	print "$TS::TS_reqedit_appaccept.<br>";

	open(EL, "$path_data/oldperm/edit1");
	my $edits = <EL>;
	close(EL);

	my $totaledits = $edits+1;

	open(LDATA2, ">$path_data/oldperm/edit1");
	print LDATA2 "$totaledits";
	close(LDATA2);

	#unlink("$path_data/nperms/$app.req");
	move("$path_data/nperms/$app.req", "$path_data/oldperm/$totaledits-$rapp2[1]-$totaledits.req");
}

#View NewApp Application

if (($review eq "newapps") && ($app ne "") && ($cmd eq "")) {
	header();

	Editor::catmodPriv($rapp[0]);
	testEmpty($rapp[1]);

	my $emailok = checkEmail($rapp[2]);

        if ($emailok eq "1") {
                $emailok = " ";
        }	
	if ($emailok ne " ") {
		$emailok = "$bold [$emailok] $unBold";
	} else {
		$emailok = " $bold [$TS::TS_reqedit_okemail] $unBold ";
	};

	my $dcat = $rapp[0];
	$dcat=~s/>/\//g;
	my $ddcat = $dcat;
	$ddcat=~s/_/ /g;

	my $forumlink = getForumLink($app, $rapp[1], $ddcat, "napps");

	writeHTMLHeader($TS::TS_reqedit_newapp);

	print <<END;
<font size="5">$TS::TS_common_editor:
 $rapp[1]</font> <font size="4">($forumlink)</font><tr>
    <td width="100%" bgcolor="$UI::box[$UI::currentskin]">$TS::TS_common_category:
END
	listCatWithLinks($ddcat);
	print <<END;
</td></tr>
<tr>
    <td width="100%" bgcolor="$UI::box[$UI::currentskin]">$TS::TS_reqedit_email: $rapp[2] $emailok<tr>
    <td width="100%" bgcolor="$UI::box[$UI::currentskin]">IP:
    <a href="iplookup.cgi?IP=$rapp[4]">$rapp[4]</a></td>
    <tr><td width="100%" bgcolor="$UI::box[$UI::currentskin]">$TS::TS_reqedit_subtime: $rapp[5]</td>
    <tr>
    <td width="100%" bgcolor="$UI::box[$UI::currentskin]">
END

	checkAlreadyEditor($rapp[1], $review, $app);

	print "$TS::TS_reqedit_reason: $rapp[6]<br>";
	print "$TS::TS_reqedit_affiliation: $rapp[7]<br>";
	print "$TS::TS_reqedit_sample_content: $rapp[8]<br>";

	#displayIt(5, @rapp);
	generateCommonHTML($app, $ddcat, $review);
	print "</table>";
}

#View Reinstate Request

if (($review eq "reinstate") && ($app ne "") && ($cmd eq "")) {
	header();

	testEmpty($rinstateapp[0]);

	my $forumlink = getForumLink($app, $rinstateapp[0], "reinstate", "nrins");

	writeHTMLHeader($TS::TS_reqedit_reinsr2);

	print <<END;
<font size="5">$TS::TS_common_editor:
  <a href="logs.cgi?name=$rinstateapp[0]&what=4">$rinstateapp[0]</a></font> <font size="4">($forumlink)</font><tr>
    <td width="100%" bgcolor="$UI::box[$UI::currentskin]">$TS::TS_reqedit_email: $rinstateapp[1]<tr>
    <td width="100%" bgcolor="$UI::box[$UI::currentskin]">IP:
    <a href="iplookup.cgi?IP=$rinstateapp[2]">$rinstateapp[2]</a></td>
    <tr><td width="100%" bgcolor="$UI::box[$UI::currentskin]">$TS::TS_reqedit_subtime: $rinstateapp[3]</td>
    <tr>
    <td width="100%" bgcolor="$UI::box[$UI::currentskin]">
END

	print "$TS::TS_reqedit_reason:<br>";

	displayIt(3, @rinstateapp);
	generateCommonHTML($app, "reinstate", $review);
	print "</table>";
}

#View NewPerm

if (($review eq "newperms") && ($app ne "") && ($cmd eq "")) {
	header();

	testEmpty($rapp2[0]);
	Editor::catmodPriv($rapp2[0]);

	my $dcat = $rapp2[0];
	$dcat=~s/>/\//g;
	my $ddcat = $dcat;
	$ddcat=~s/_/ /g;

	my $forumlink = getForumLink($app, $rapp2[0], $ddcat, "nperms");

	writeHTMLHeader($TS::TS_reqedit_newperm);

	print <<END;
<font size="5">$TS::TS_common_editor:
 <a href="logs.cgi?name=$rapp2[1]&what=4">$rapp2[1]</a></font> <font size="4">($forumlink)</font><tr>
    <td width="100%" bgcolor="$UI::box[$UI::currentskin]">
END

	my $enamel = $rapp2[1];
	EditorProfile::profilenote($rapp2[1]);
	print <<END;
    </td></tr>
    <tr>
    <td width="100%" bgcolor="$UI::box[$UI::currentskin]">$TS::TS_common_category:
END
	listCatWithLinks($ddcat);
	print <<END;

</td></tr>
<tr>
    <td width="100%" bgcolor="$UI::box[$UI::currentskin]">$TS::TS_reqedit_subtime:
    $rapp2[4]</td></tr>
<tr>
    <td width="100%" bgcolor="$UI::box[$UI::currentskin]">$TS::TS_reqedit_reason: $rapp2[5]<br>
    $TS::TS_reqedit_affiliation: $rapp2[6]<br>
    $TS::TS_reqedit_sample_content: $rapp2[7]
END
	#displayIt(4, @rapp2);
	generateCommonHTML($app, $ddcat, $review);

	print <<END;
</table><br>
<H1>Request Log</H1><hr>
<table border="1" id="AutoNumber1" cellpadding="2">
END
	print <<END;
  <tr>
    <td>Date</td>
    <td>Who</td>
    <td>Action</td>
    <td>Comments</td>
  </tr>
END
	my @rlog2 = getContent("$path_data/logs/rootlog/areqeditlog.log");

	my $rlog = "";
	@rlog2 = grep { /##!!## $rapp2[1] / } @rlog2;
	for (my $d = 0; $d <= $#rlog2; $d++) {
		$rlog = "$rlog $rlog2[$d]";
	}

	$rlog=~s/\>/\//g;
	$rlog=~s/ ##!!## $rapp2[1]/ /g; #<td bgcolor="#CCCCCC"> /g;
	$rlog=~s/ \#!\#/ <\/td> /g;
	$rlog=~s/ \#\#!\#\#/ <td> /g;
	$rlog=~s/ \#\#!!!\#\# / <td> /g;
	$rlog=~s/ \#\#!!!!\#\# / <\/td><\/tr> /g;

	opendir(DIR, "$path_sitedata/");
	my @edits = readdir(DIR);
	closedir(DIR);

	chomp(@edits);
	foreach (@edits) {
		if ($_=~/.html/) {
			$_=~s/.html//g;
			$_=~s/\>/\//g;
			my $ook = " <a href=\"./editcat.cgi?cat=$_\">$_</a> ";
			$rlog=~s/ $_ /$ook/g;
		}
	}

	print $rlog;
	print "</table>";
}

#Show List of Reinstatement Requests

if (($review eq "reinstate") && ($app eq "")) {
	header();

	writeHTMLHeader($TS::TS_reqedit_reinsr);

	tableHeader();

	opendir(DIR,"$path_data/nrins");
	my @files = readdir(DIR);
	closedir(DIR);

	$files[0] = "XXXX##XXXX";
	$files[1] = "XXXX##XXXX";
	#$files[2] = "XXXX##XXXX";

 	chomp(@files);

	foreach (@files) {
      	if ($_ eq "XXXX##XXXX") {
		} else {
			$_=~s/.req//g;
			open(DCATS, "$path_data/nrins/$_.req");
			my @rapp = <DCATS>;
			close(DCATS);
			$rapp[0]=~s/>/\//g;
			$rapp[0]=~s/[\n\r]//g;
			$rapp[3]=~s/[\n\r]//g;
			print <<END;
<tr>
  <td valign="Top">
    <a href="reqedit.cgi?review=reinstate&app=$_">$rapp[0]</a>
  </td>
  <td valign="Top">
  </td>
  <td>
    $rapp[3]
  </td>
</tr>
END
		}
	}

	if ($files[2] eq "") {
		print "$TS::TS_reqedit_nnaiq";
	}
	print <<END;
</tbody></table>
</font></table>
END

}


#Show List of NewApps

if (($review eq "newapps") && ($app eq "")) {
	header();

	writeHTMLHeader($TS::TS_reqedit_newapps);

	tableHeader($TS::TS_common_category);

 	opendir(DIR, "$path_data/napps");
	my @files = readdir(DIR);
	closedir(DIR);

	$files[0] = "XXXX##XXXX";
	$files[1] = "XXXX##XXXX";
	#$files[2] = "XXXX##XXXX";

	chomp(@files);

	foreach (@files) {
		if ($_ eq "XXXX##XXXX") {
		} else {
			$_=~s/.req//g;

			open(DCATS, "$path_data/napps/$_.req");
			@rapp = <DCATS>;
			close(DCATS);
			$rapp[0]=~s/>/\//g;
			$rapp[0]=~s/[\n\r]//g;
			print <<END;
<tr>
  <td valign="Top">
    <a href="reqedit.cgi?review=newapps&app=$_">$rapp[1]</a>
  </td>
  <td valign="Top">
END
			listCatWithLinks($rapp[0]);
			print <<END;
  </td>
  <td>
    $rapp[5]
  </td>
</tr>
END
		}
	}

	if ($files[2] eq "") {
		print "$TS::TS_reqedit_nnaiq";
	}
	print <<END;
</tbody>
</table>
</font>
</table>
END
}

#Show List of NewPerms

if (($review eq "newperms") && ($app eq "")) {
	header();

	writeHTMLHeader($TS::TS_reqedit_newperms);

	opendir(DIR,"$path_data/nperms");
	my @files = readdir(DIR);
	closedir(DIR);

	$files[0] = "XXXX##XXXX";
	$files[1] = "XXXX##XXXX";

	tableHeader($TS::TS_common_category);

	chomp(@files);
	foreach (@files) {
		if (!($_ eq "XXXX##XXXX")) {
			$_=~s/.req//g;
			@rapp2 = getContent("$path_data/nperms/$_.req");
			$rapp2[0]=~s/>/\//g;
			$rapp2[0]=~s/[\n\r]//g;
			$rapp2[1]=~s/[\n\r]//g;
			$rapp2[4]=~s/[\n\r]//g;
			
			print <<END;
    <tr>
      <td valign="Top">
        <a href="reqedit.cgi?review=newperms&app=$_">$rapp2[1]</a>
      </td>
      <td valign="Top">
END
			listCatWithLinks($rapp2[0]);
			print <<END;
      </td>
      <td valign="Top">
        $rapp2[4]
      </td>
    </tr>
END
		}
	}

	if ($files[2] eq "") {
                print $TS::TS_reqedit_nnriq;
	}
	print <<END;
  </tbody>
</table>
</font>
</table>
END
}

if (($review eq "") && ($cmd eq "")) {
	header();
}

generateFooter($review, $app);
