#!/usr/bin/perl -wT
#************************************************************************
#
# The contents of this file are subject to the Mozilla Public License
# Version 1.1 (the "License"); you may not use this file except in
# compliance with the License. You may obtain a copy of the License at
# http://www.mozilla.org/MPL/
#
# Software distributed under the License is distributed on an "AS IS"
# basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
# License for the specific language governing rights and limitations
# under the License.
#
#
# The Original Code is Open-site.
#
# The Initial Developer of the Original Code is Open-site.org Website.
#
# Portions created by Open-site.org are Copyright (C) 2002.
# All Rights Reserved.
#
#************************************************************************


use strict;
use CGI;

use lib '.';
use Include;
use Editor;
use Settings;
use TS;
use UI;


# Returns an array with names of the files that can be translated
# Params: 0
# Returns: the array

sub getAvailSections {
	my @fil = ();
	if (open(FIL, "$path_code/ts/editable.txt")) {
		@fil = <FIL>;
		close(FIL);
	}
	
	return @fil;
}


# Returns an array with the languages available for translation
# Params: 0
# Returns: the array

sub getAvailLanguages {
	my @fil = ();
	if (open(FIL, "$path_code/ts/langs.txt")) {
		@fil = <FIL>;
		close(FIL);
	}
	
	return @fil;
}


# Checks if the current user has access to a specified language
# Params: 1
# Param 1: the language to be tested
# Returns: nothing (but if access is denied, the execution is halted)

sub testLanguage
{
	my ($lang) = @_;

	my @langs = getAvailLanguages();

	my $cUser = Editor::currentUser();
	my $perms = "";
	if (open(DCATS, "$path_data/eperm/$cUser.perm")) {
		$perms = <DCATS>;
		close(DCATS);
	}

	my $okay = 0;
	if ($isFullEditall eq "1") {
		$okay = 1;
	}

	my $language = $langs[$lang - 1];
	$language=~s/[\n\r]//g;

	if (($perms=~/ International; /) || ($perms=~/ International>$language; /)) {
		$okay = 1;
	}

	if ($okay eq "0") {
		print "Error - the credentials supplied do not grant you access to this area.";
		UI::writeScriptFooter();
		exit(0);
	}
}

sub TSstatus {
	my($errors, $color, $message, $content);
	$errors = 0;
	$content = "";

	my @fil = getAvailSections();

	my $p = 0;
	for (my $i = 0; $i <= $#fil; $i++) {
		$fil[$i]=~s/\s//g;
		open(FIL, "$path_code/ts/1$fil[$i].pl");
		my @english = <FIL>;
		close(FIL);

		my @source = ();
		if (open(FIL, "$path_web/editors/$fil[$i].cgi")) {
			@source = <FIL>;
			close(FIL);
		}

		my @source2 = ();
		if (open(FIL, "$path_web/$fil[$i].cgi")) {
			@source2 = <FIL>;
			close(FIL);
		}

		my $source = join("", @source) . join("", @source2);

		if (($fil[$i] ne "common") && ($fil[$i] ne "cat") && ($fil[$i] ne "logs") && ($fil[$i] ne "forum")) {
			for (my $x = 0; $x <= $#english; $x++) {
				if ($english[$x]=~/(TS[^ ]*)/) {
					$english[$x] = $1;
					if (index($source, $english[$x]) == -1) {
						$content = $content .
						"<br>$english[$x] not found in the target source file.";
						$errors++;
					}
				}
			}
		}
	}

	@fil = getAvailSections();
	my $editable = " " . join(" ", @fil) . " ";

	opendir(DIR, "$path_code/ts");
	my @dir = readdir(DIR);
	closedir(DIR);

	for (my $x = 2; $x <= $#dir; $x++) {
		if ($dir[$x]=~/\.pl/) {
			my $search = $dir[$x];
			$search=~s/^[0-9]*//g;
			$search=~s/\.pl//g;
			if (!($editable=~/$search/)) {
				$content .= "<br>$dir[$x] not found among allowed TS files.";
				$errors++;
			}
		}
	}

	if ($errors) {
		$color = "#ffaaaa";
		$message = "<p>$errors error(s) detected.<br>$content";
	} else {
		$color = "#aaffaa";
		$message = "Strings okay.";
	}
	
	print <<END;
<p>
  <table align="center" border="0" cellspacing="1" cellpadding="1" width="70%" bgcolor="#000000">
    <tr>
      <td bgcolor="$color">
        <b>Root-only status message
        - Translation strings consistency check</b>
      </td></tr>
    <tr>
      <td bgcolor="$color">$message</td>
    </tr>
  </table>
</p>
END
}

sub viewLog
{
	my($reditor, $rsection, $rlang) = @_;
	
	if (!defined $reditor) {
		$reditor = "";
	}
	
	if (!defined $rsection) {
		$rsection = "";
	}
	
	if (!defined $rlang) {
		$rlang = "";
	}

	my $langSel = "<select name=\"restrictlang\"><option value=\"*\">Any";
	
	my @fil = getAvailLanguages();

	for (my $d = 0; $d <= $#fil; $d++) {
		my $id = $d + 1;
		my $selected = ($rlang eq $id) ? " selected" : "";
		
		$langSel .= "<option value=\"$id\"$selected>$fil[$d]";
	}
	$langSel .= "</select>";
	
	open(LOG, "$path_code/ts/log.txt");
	my @log = <LOG>;
	close(LOG);

	print <<END;
<p align="center">
  $TS::TS_translate_query<br>
  <form method="get" action="translate.cgi">
    $TS::TS_common_editor:
    <input name="restricteditor" value="$reditor" type="text"><br>
    $TS::TS_translate_section:
    <input name="restrictsection" value="$rsection" type="text"><br>
    $TS::TS_translate_loglang: $langSel<br>
    <input type="submit" name="viewlog" value="$TS::TS_common_submit">
  </form>
</p>
<p>
  <table width="100%">
    <tr align="center" bgcolor="#f0f4e8">
      <td width="20%">$TS::TS_translate_datetime</td>
      <td>$TS::TS_common_editor</td>
      <td>$TS::TS_translate_section</td>
      <td>$TS::TS_translate_loglang</td>
      <td>$TS::TS_translate_string</td>
      <td>$TS::TS_translate_translation</td>
    </tr>
END

	@fil = getAvailLanguages();

	my $people = "<p>The following people have contributed to the translation strings:<br>";

	for (my $i = 0; $i <= $#log; $i++) {
		if ($log[$i]=~/^[^\s|]*\|/) {
			#No time information
			$log[$i]=~s/</&lt;/g;
			$log[$i]=~s/>/&gt;/g;
			if ($log[$i]=~/([^\|]*)\|([^\|]*)\|([^\|]*)\|([^\|]*)\|([^\|]*)\n/) {
				my $lg = $fil[$3 - 1];
				if ((($reditor eq "*") || ($reditor eq $1)) && (($rsection eq "*") || ($rsection eq $2)) && (($rlang eq "*") || ($rlang eq $3)))
				{
					print "<tr align=\"center\" bgcolor=\"#f0f0f0\"><td>?</td><td>$1</td><td>$2</td><td>$lg</td><td align=left>$4</td><td align=\"left\">$5</td></tr>\n";
				}
				my $ed = $1;
				if (!($people=~/$ed/)) {
					$people.=", <a href=\"profile.cgi?editor=$ed\" title=\"$ed\">$ed</a>";
				}
			}
		} else {
			$log[$i]=~s/</&lt;/g;
			$log[$i]=~s/>/&gt;/g;
			if ($log[$i]=~/([^\|]*)\|([^\|]*)\|([^\|]*)\|([^\|]*)\|([^\|]*)\|([^\|]*)\n/) {
				my $lg = $fil[$4 - 1];
				if ((($reditor eq "*") || ($reditor eq $2)) && (($rsection eq "*") || ($rsection eq $3)) && (($rlang eq "*") || ($rlang eq $4))) {
					print "<tr align=\"center\" bgcolor=\"#f0f0f0\"><td>$1</td><td>$2</td><td>$3</td><td>$lg</td><td align=left>$5</td><td align=\"left\">$6</td></tr>\n";
				}
				my $ed = $2;
				if (!($people=~/$ed/)) {
					$people.=", <a href=\"profile.cgi?editor=$ed\" title=\"$ed\">$ed</a>";
				}
			}
		}
	}
	$people=~s/<br>, /<br>/;
	print "</table></p>$people";
	print "<p><a href=\"translate.cgi\">$TS::TS_translate_back</a></p>";
}

sub viewStatus {
	
	my @list = getAvailLanguages();
	my @fil = getAvailSections();

	print <<END;
<p><table><tr bgcolor="#e0e0e0"><th width="1%">No.</th><th width="1%">Language</th>
<th>Status</th><th width="1%">#&nbsp;translated</th><th width="1%">%&nbsp;done</th></tr>
END
	my $color = "#f0f0f0";
	my $ref = 0;
	for (my $d = 0; $d <= $#list; $d++) {
		if ($color eq "#f0f0f0") {
			$color = "#eaf0fa";
		} else {
			$color = "#f0f0f0";
		}

		my $e = $d + 1;
		my $total = 0;
		for (my $i = 0; $i <= $#fil; $i++) {
			$fil[$i] =~s/[\n\r]*//g;
			if (open(FIL, "$path_code/ts/$e$fil[$i].pl")) {
				my @content = <FIL>;
				close(FIL);
				$total += $#content + 1;
			}
		}
		if (!$ref) {
			$ref = $total;
		}
		my $perc = int($total / $ref * 1000) / 10;
		my $width = int($total / $ref * 100);
		my $width2 = 100 - $width;
		if (!($perc =~/\./)) {
			$perc .= ".0";
		}
		$perc .= "&nbsp;%";

		print <<END;
<tr bgcolor="$color">
<td align="center"><strong>$e</strong></td>
<td><strong><a href="translate.cgi?lang=$e">$list[$d]</a></strong></td>
<td>
  <table width="100%" cellspacing="0">
    <tr>
END
		if ($width > 0) {
			print <<END;
      <td width="$width%" bgcolor="#33ff44">&nbsp;</td>
END
		}
		if ($width2 > 0) {
			print <<END;
      <td width="$width2%" bgcolor="#ffaaaa">&nbsp;</td>
END
		}
		print <<END;
    </tr>
  </table>
</td>
<td align="center"><strong>$total</strong></td>
<td align="right"><strong>$perc</strong></td>
</tr>
END
	}
	print "</table><p><a href=\"translate.cgi\">$TS::TS_translate_back</a></p>";
}

sub viewIndex
{
	my($cgi, $act3) = @_;

	if (defined $act3) {
		open(FIL, ">$path_code/ts/langs.txt");
		print FIL $cgi->param('arg1');
		close(FIL);

		open(FIL, ">$path_code/ts/editable.txt");
		print FIL $cgi->param('arg2');
		close(FIL);
	}

	if ($isRoot) {
		TSstatus();
	}

	my @fil = getAvailLanguages();
	$fil[0] = "<option value=\"1\">English";

	my $cUser = Editor::currentUser();
	my $perms = "";
	if (open(DCATS, "$path_data/eperm/$cUser.perm")) {
		$perms = <DCATS>;
		close(DCATS);
	}

	for (my $i = 1; $i <= $#fil; $i++) {
		my $okay = 0;
		if ($isFullEditall eq "1") {
			$okay = 1;
		}
		$fil[$i]=~s/[\n\r]//g;
		if (($perms=~/ International; /) || ($perms=~/ International>$fil[$i]; /)) {
			$okay = 1;
		}

		if ($okay eq "1") {
			$fil[$i] = "<option value=\"" . ($i + 1) . "\">" . $fil[$i];
		} else {
			$fil[$i] = "";
		}
	}

	#English strings are root-only
	if ($isRoot ne "1") {
		$fil[0] = "";
	}

	my $fil = join ("", @fil);
	
	my @langs = getAvailLanguages();
	my $langs = join("", @langs);

	my @files = getAvailSections();
	my $files = join("", @files);

	print <<END;
<form method="get" action="translate.cgi">
  $TS::TS_translate_lang:
  <select name="lang">$fil</select> &nbsp; &nbsp; &nbsp;
  <input type="submit" value="$TS::TS_translate_translate">
</form>

<p>
  <a href="translate.cgi?viewlog=1">$TS::TS_translate_logs</a> &nbsp;
  <a href="translate.cgi?viewstatus=1">View status</a>
</p>
END

	if ($isRoot eq "1") {
		print <<END;
<form method="post" action="translate.cgi">
  <p>$TS::TS_translate_admin</p>
  <p>$bold$TS::TS_translate_languages:$unBold<br>
  <textarea name="arg1" rows="5" cols="70">$langs</textarea>
  </p>
  <p>$bold$TS::TS_translate_files:$unBold<br>
  <textarea name="arg2" rows="5" cols="70">$files</textarea>
  </p>
  <p><input type="submit" name="act3" value="$TS::TS_common_submit">
</form>
END
	}
}

sub viewIndex2
{
	my($lang) = @_;

	my @langs = getAvailLanguages();
	my $cUser = Editor::currentUser();
	
	my $perms = "";
	if (open(DCATS, "$path_data/eperm/$cUser.perm")) {
		$perms = <DCATS>;
		close(DCATS);
	}

	my $okay = 0;
	if ($isFullEditall eq "1") {
		$okay = 1;
	}

	my $language = $langs[$lang - 1];
	$language=~s/[\n\r]//g;

	if (($perms=~/ International; /) || ($perms=~/ International>$language; /)) {
		$okay = 1;
	}

	print "<p>$TS::TS_translate_lang $lang - $langs[$lang - 1]...</p>";

	if ($okay == 1) {
		print "<p>$TS::TS_translate_selfile:</p>";
	}

	my @fil = getAvailSections();

	print "<center><table width=\"85%\"><tr><td colspan=\"3\" bgcolor=\"#ddffee\">$TS::TS_translate_files:</td></tr>";
	my $p = 0;
	for (my $i = 0; $i <= $#fil; $i++) {
		if ($p eq "0") {
			print "<tr bgcolor=\"#ffffee\">";
		}
		$fil[$i]=~s/\s//g;
		open(FIL, "$path_code/ts/$lang$fil[$i].pl");
		my @content = <FIL>;
		close(FIL);
		open(FIL, "$path_code/ts/1$fil[$i].pl");
		my @english = <FIL>;
		close(FIL);
		my $eng = $#english + 1;
		my $con = $#content + 1;
		print "<td>";
		if ($okay == 1) {
			print "<a href=\"translate.cgi?lang=$lang&file=$fil[$i]&act=Translate\">";
		}
		print "$fil[$i]";
		if ($okay == 1) {
			print "</a>";
		}
		print " ($eng $TS::TS_translate_strings";
		if ($con ne $eng) {
			my $newst = $eng - $con;
			print ", <u>$newst $TS::TS_translate_new</u>";
		}
		print ")</td>";
		$p++;
		if ($p == 3) {
			print "</tr>";
			$p = 0;
		}
	}
	
	while ($p != 0) {
		$p++;
		if ($p == 3) {
			print "</tr>";
			$p = 0;
		}
	}
	
	print "</table></center>";
}

sub translateFile
{
	my($lang, $file) = @_;
	my($txtString, $txtEnglish, $txtTranslated);

	testLanguage($lang);

	print "<p>$TS::TS_translate_tfile $lang$file.pl ...</p>";
	open(FIL, "$path_code/ts/$lang$file.pl");
	my @content = <FIL>;
	close(FIL);
	open(FIL, "$path_code/ts/1$file.pl");
	my @english = <FIL>;
	close(FIL);
	my $cont = join(" ", @content);
	print <<END;
<form method="post" action="translate.cgi">
  <input type="hidden" name="file" value="$file">
  <input type="hidden" name="lang" value="$lang">
  <input type="hidden" name="numbers" value="$#english">
  <p>
    <table width="100%" border="1" cellspacing="0" cellpadding="0">
      <tr align="center">
        <td width="50%">String</td>
        <td width="50%">$TS::TS_translate_englishtrans</td>
        <td>$TS::TS_translate_ctran</td>
      </tr>
END
	for (my $i = 0; $i <= $#english; $i++) {
		if ($english[$i]=~/([^\s]*) = "([^;"]*)";/) {
			$txtString = $1;
			$txtEnglish = $2;
		}
		$txtString=~s/\$(.*)/$1/g;
		$txtTranslated = "";
		if ($cont=~/$txtString = "([^;"]*)";/) {
			$txtTranslated = $1;
		}
		my $composedText = "\$" . "$txtString";
		print <<END;
      <tr>
        <td>$composedText</td>
        <td>$txtEnglish</td>
        <td><textarea name="$i" rows="3" cols="30">$txtTranslated</textarea></td>
      </tr>
END
	}
	my $composedText = "\$" . "TS_" . $file . "_";
	print <<END;
      <tr align="center">
        <td>New string:
          <input type="text" size="40" name="newTS" value="$composedText">
        </td>
        <td colspan="2">
          <textarea name="newTR" rows="3" cols="60"></textarea>
        </td>
      </tr>
    </table>
  </p>
  <p>
    <input name="act2" type="submit" value="$TS::TS_common_submit">
  </p>
</form>
END
}

sub translateFile2
{
	my($lang, $file, $cgi) = @_;
	my($txtString, $txtEnglish, $textes, $tempfix);

	testLanguage($lang);

	open(FIL, "$path_code/ts/1$file.pl");
	my @english = <FIL>;
	close(FIL);
	
	open(FIL, "$path_code/ts/$lang$file.pl");
	my @comlog = <FIL>;
	close(FIL);
	my $comlog = join("", @comlog);
	
	open(LOG, ">>$path_code/ts/log.txt");
	my $numbers = $cgi->param('numbers');

	open(FIL, ">$path_code/ts/$lang$file.pl");

	my $i;
	for ($i = 0; $i <= $numbers; $i++) {
		if ($english[$i]=~/([^\s]*) = "([^;"]*)";/) {
			$txtString = $1;
			$txtEnglish = $2;
		}
		$textes = $cgi->param($i);
		$textes=~s/|//g;
		$textes=~s/;//g;
		$textes=~s/""//g;
		$textes=~s/\"//g;
		$textes=~s/\$//g;
		$textes=~s/[\n\r]/ /g;
		if ($textes ne "") {
			print FIL $txtString . " = \"" . $textes . "\";\n";
			$tempfix = $txtString;
			$tempfix=~s/\$(.*)/$1/g;
			$textes=~s/\(/\\\(/g;
			$textes=~s/\)/\\\)/g;
			$textes=~s/\?/\\\?/g;
			$textes=~s/\"/\\\"/g;
			$textes=~s/\$/\\\$/g;
			$textes=~s/\[/\\\[/g;
			$textes=~s/\]/\\\]/g;
			$textes=~s/\{/\\\{/g;
			$textes=~s/\}/\\\}/g;
			$textes=~s/\+/\\\+/g;
			if ($comlog=~/\$$tempfix = \"$textes\";/)
			{
				#Entry not modified, do not log
			} else {
				my $lt = localtime;
				print LOG "$lt|$ENV{REMOTE_USER}|$file|$lang|".$txtString."|".$cgi->param($i)."\n";
			}
		}
	}
	if ($cgi->param('newTR') ne "") {
		my($newTS) = $cgi->param('newTS');
		my($newTR) = $cgi->param('newTR');
		my $lt = localtime;
		print FIL $newTS . " = \"" . $newTR . "\";\n";
		print LOG "$lt|$ENV{REMOTE_USER}|$file|$lang|".$txtString."|".$cgi->param($i)."\n";
	}
	close(FIL);
	close(LOG);
	print "<p>$TS::TS_translate_savedchanges</p>";
	print "<p><a href=\"translate.cgi?lang=$lang\">$TS::TS_common_back</a></p>";
}

my $cgi = new CGI;

UI::writeHeaderCode("Translation Tool");
Editor::writeECode();

my $user = Editor::currentUser();

my $file = $cgi->param('file');
my $lang = $cgi->param('lang');
my $act = $cgi->param('act');
my $act2 = $cgi->param('act2');
my $act3 = $cgi->param('act3');
my $viewlog = $cgi->param('viewlog');
my $viewstatus = $cgi->param('viewstatus');
my $reditor = $cgi->param('restricteditor');
my $rsection = $cgi->param('restrictsection');
my $rlang = $cgi->param('restrictlang');
my $cat = $cgi->param('cat');
my $lt = localtime;

$file = Storage::validateFileName($file);
$lang = Storage::validateFileName($lang);

if (!defined $lang) {
	$lang = "";
}

if (($lang eq "") && (defined $cat)) {
	my @langs = getAvailLanguages();

	$cat=~s/\//\>/g;
	$cat=~s/\\/>/g;
	if ($cat=~/^[^>]*\>(.*)$/) {
		$cat = $1;
	}

	for (my $d = 0; $d <= $#langs; $d++) {
		my $compare = $langs[$d];
		$compare=~s/[\n\r]//g;
		if ($compare eq $cat) {
			$lang = $d + 1;
		}
	}
}

our @langs = getAvailLanguages();

if ($lang ne "") {
	if ($lang!~/^([0-9]+)$/) {
		die ("Invalid data format for lang CGI param.");
	} else {
		$lang = $1;
	}

	$lang = $lang * 2;
	$lang = $lang / 2;

	if ($#langs + 1 < $lang) {
		$lang = "";
		print "$TS::TS_translate_badid";
	}
}

if ($lang eq "0") {
	$lang = "";
}

if ($lang eq "1") {
	if ($isRoot ne "1") {
		#English strings are root-only
		$lang = "";
		print "$TS::TS_translate_badid";
	}
}

if (defined $viewlog) {
	viewLog($reditor, $rsection, $rlang);
} elsif (defined $viewstatus) {
	viewStatus();
} elsif ($lang eq "") {
	viewIndex($cgi, $act3);
} else {
	if (($act eq "") && ($act2 eq "")) {
		viewIndex2($lang);
	} elsif ($act ne "") {
		translateFile($lang, $file);
	} else {
		translateFile2($lang, $file, $cgi);
	}

	print "<p><a href=\"translate.cgi\">$TS::TS_translate_another</a></p>";
}

UI::writeScriptFooter();
